"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QStyledItemDelegate(QAbstractItemDelegate):
    """
    https://doc.qt.io/qt-6/qstyleditemdelegate.html

    **Detailed Description**

    When displaying data from models in Qt item views, e.g., a **QTableView** ,
    the individual items are drawn by a delegate. Also, when an item is edited,
    it provides an editor widget, which is placed on top of the item view while
    editing takes place. QStyledItemDelegate is the default delegate for all Qt
    item views, and is installed upon them when they are created.

    The QStyledItemDelegate class is one of the **Model/View Classes**  and is
    part of Qt's **model/view framework** . The delegate allows the display and
    editing of items to be developed independently from the model and view.

    The data of items in models are assigned an **ItemDataRole** ; each item can
    store a **QVariant**  for each role. QStyledItemDelegate implements display
    and editing for the most common datatypes expected by users, including
    booleans, integers, and strings.

    The data will be drawn differently depending on which role they have in the
    model. The following table describes the roles and the data types the
    delegate can handle for each of them. It is often sufficient to ensure that
    the model returns appropriate data for each of the roles to determine the
    appearance of items in views.

    RoleAccepted Types
    **Qt::BackgroundRole** **QBrush**  (
    **Qt::CheckStateRole** **Qt::CheckState**
    **Qt::DecorationRole** **QIcon**
    , **QPixmap** , **QImage**  and **QColor**
    **Qt::DisplayRole** **QString**
    and types with a string representation
    **Qt::EditRole** See
    **QItemEditorFactory**  for details
    **Qt::FontRole** **QFont**
    **Qt::SizeHintRole** **QSize**
    **Qt::TextAlignmentRole** **Qt::Alignment**
    **Qt::ForegroundRole** **QBrush**  (

    Editors are created with a **QItemEditorFactory** ; a default static
    instance provided by **QItemEditorFactory**  is installed on all item
    delegates. You can set a custom factory using **setItemEditorFactory** () or
    set a new default factory with **QItemEditorFactory::setDefaultFactory** ().
    It is the data stored in the item model with the **EditRole**  that is
    edited. See the **QItemEditorFactory**  class for a more high-level
    introduction to item editor factories. The **Color Editor Factory**  example
    shows how to create custom editors with a factory.

    **Subclassing QStyledItemDelegate**

    If the delegate does not support painting of the data types you need or you
    want to customize the drawing of items, you need to subclass
    QStyledItemDelegate, and reimplement **paint** () and possibly **sizeHint**
    (). The **paint** () function is called individually for each item, and with
    **sizeHint** (), you can specify the hint for each of them.

    When reimplementing **paint** (), one would typically handle the datatypes
    one would like to draw and use the superclass implementation for other
    types.

    The painting of check box indicators are performed by the current style. The
    style also specifies the size and the bounding rectangles in which to draw
    the data for the different data roles. The bounding rectangle of the item
    itself is also calculated by the style. When drawing already supported
    datatypes, it is therefore a good idea to ask the style for these bounding
    rectangles. The **QStyle**  class description describes this in more detail.

    If you wish to change any of the bounding rectangles calculated by the style
    or the painting of check box indicators, you can subclass **QStyle** . Note,
    however, that the size of the items can also be affected by reimplementing
    **sizeHint** ().

    It is possible for a custom delegate to provide editors without the use of
    an editor item factory. In this case, the following virtual functions must
    be reimplemented:

    * **createEditor** () returns the widget used to change data from the model
    and can be reimplemented to customize editing behavior.
      *
    **setEditorData** () provides the widget with data to manipulate.
      *
    **updateEditorGeometry** () ensures that the editor is displayed correctly
    with respect to the item view.
      * **setModelData** () returns updated data
    to the model.

    The **Star Delegate**  example creates editors by reimplementing these
    methods.

    **QStyledItemDelegate vs. QItemDelegate**

    Since Qt 4.4, there are two delegate classes: **QItemDelegate**  and
    QStyledItemDelegate. However, the default delegate is QStyledItemDelegate.
    These two classes are independent alternatives to painting and providing
    editors for items in views. The difference between them is that
    QStyledItemDelegate uses the current style to paint its items. We therefore
    recommend using QStyledItemDelegate as the base class when implementing
    custom delegates or when working with Qt style sheets. The code required for
    either class should be equal unless the custom delegate needs to use the
    style for drawing.

    If you wish to customize the painting of item views, you should implement a
    custom style. Please see the **QStyle**  class documentation for details.

    **See also** **Delegate Classes** , **QItemDelegate** ,
    **QAbstractItemDelegate** , **QStyle** , **Spin Box Delegate Example** ,
    **Star Delegate Example** , and **Color Editor Factory Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#QStyledItemDelegate

        **QStyledItemDelegate::QStyledItemDelegate(QObject * parent = nullptr)**

        Constructs an item delegate with the given **parent**.
        """
        ...

    def editorEvent(
        self,
        event: QtCore.QEvent,
        model: QtCore.QAbstractItemModel,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#editorEvent

        **[override virtual protected] bool
        QStyledItemDelegate::editorEvent(QEvent * event , QAbstractItemModel *
        model , const QStyleOptionViewItem & option , const QModelIndex & index
        )**

        Reimplements: **QAbstractItemDelegate::editorEvent** (QEvent *event,
        QAbstractItemModel *model, const QStyleOptionViewItem &option, const
        QModelIndex &index).
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#eventFilter

        **[override virtual protected] bool
        QStyledItemDelegate::eventFilter(QObject * editor , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).

        Returns `true` if the given **editor** is a valid **QWidget**  and the
        given **event** is handled; otherwise returns `false`. The following key
        press events are handled by default:

        * **Tab**
          * **Backtab**
          * **Enter**
          * **Return**
          * **Esc**

        If the **editor** 's type is **QTextEdit**  or **QPlainTextEdit**  then
        **Enter** and **Return** keys are **not** handled.

        In the case of **Tab** , **Backtab** , **Enter** and **Return** key
        press events, the **editor** 's data is committed to the model and the
        editor is closed. If the **event** is a **Tab** key press the view will
        open an editor on the next item in the view. Likewise, if the **event**
        is a **Backtab** key press the view will open an editor on the
        **previous** item in the view.

        If the event is a **Esc** key press event, the **editor** is closed
        **without** committing its data.

        **See also** **commitData** () and **closeEditor** ().
        """
        ...

    def initStyleOption(
        self, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#initStyleOption

        **[virtual protected] void
        QStyledItemDelegate::initStyleOption(QStyleOptionViewItem * option ,
        const QModelIndex & index ) const**

        Initialize **option** with the values using the index **index**. This
        method is useful for subclasses when they need a
        **QStyleOptionViewItem** , but don't want to fill in all the information
        themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def displayText(self, value: typing.Any, locale: QtCore.QLocale) -> str:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#displayText

        **[virtual] QString QStyledItemDelegate::displayText(const QVariant &
        value , const QLocale & locale ) const**

        This function returns the string that the delegate will use to display
        the **Qt::DisplayRole**  of the model in **locale**. **value** is the
        value of the **Qt::DisplayRole**  provided by the model.

        The default implementation uses the **QLocale::toString**  to convert
        **value** into a **QString** .

        This function is not called for empty model indices, i.e., indices for
        which the model returns an invalid **QVariant** .

        **See also** **QAbstractItemModel::data** ().
        """
        ...

    def setItemEditorFactory(self, factory: QItemEditorFactory) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#setItemEditorFactory

        **void QStyledItemDelegate::setItemEditorFactory(QItemEditorFactory *
        factory )**

        Sets the editor factory to be used by the item delegate to be the
        **factory** specified. If no editor factory is set, the item delegate
        will use the default editor factory.

        **See also** **itemEditorFactory** ().
        """
        ...

    def itemEditorFactory(self) -> QItemEditorFactory:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#itemEditorFactory

        **QItemEditorFactory *QStyledItemDelegate::itemEditorFactory() const**

        Returns the editor factory used by the item delegate. If no editor
        factory is set, the function will return null.

        **See also** **setItemEditorFactory** ().
        """
        ...

    def updateEditorGeometry(
        self, editor: QWidget, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#updateEditorGeometry

        **[override virtual] void
        QStyledItemDelegate::updateEditorGeometry(QWidget * editor , const
        QStyleOptionViewItem & option , const QModelIndex & index ) const**

        Reimplements: **QAbstractItemDelegate::updateEditorGeometry(QWidget
        *editor, const QStyleOptionViewItem &option, const QModelIndex &index)
        const** .

        Updates the **editor** for the item specified by **index** according to
        the style **option** given.
        """
        ...

    def setModelData(
        self,
        editor: QWidget,
        model: QtCore.QAbstractItemModel,
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#setModelData

        **[override virtual] void QStyledItemDelegate::setModelData(QWidget *
        editor , QAbstractItemModel * model , const QModelIndex & index )
        const**

        Reimplements: **QAbstractItemDelegate::setModelData(QWidget *editor,
        QAbstractItemModel *model, const QModelIndex &index) const** .

        Gets data from the **editor** widget and stores it in the specified
        **model** at the item **index**.

        The default implementation gets the value to be stored in the data model
        from the **editor** widget's **user property** .

        **See also** **QMetaProperty::isUser** ().
        """
        ...

    def setEditorData(self, editor: QWidget, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#setEditorData

        **[override virtual] void QStyledItemDelegate::setEditorData(QWidget *
        editor , const QModelIndex & index ) const**

        Reimplements: **QAbstractItemDelegate::setEditorData(QWidget *editor,
        const QModelIndex &index) const** .

        Sets the data to be displayed and edited by the **editor** from the data
        model item specified by the model **index**.

        The default implementation stores the data in the **editor** widget's
        **user property** .

        **See also** **QMetaProperty::isUser** ().
        """
        ...

    def createEditor(
        self, parent: QWidget, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> QWidget:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#createEditor

        **[override virtual] QWidget *QStyledItemDelegate::createEditor(QWidget
        * parent , const QStyleOptionViewItem & option , const QModelIndex &
        index ) const**

        Reimplements: **QAbstractItemDelegate::createEditor(QWidget *parent,
        const QStyleOptionViewItem &option, const QModelIndex &index) const** .

        Returns the widget used to edit the item specified by **index** for
        editing. The **parent** widget and style **option** are used to control
        how the editor widget appears.

        **See also** **QAbstractItemDelegate::createEditor** ().
        """
        ...

    def sizeHint(
        self, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#sizeHint

        **[override virtual] QSize QStyledItemDelegate::sizeHint(const
        QStyleOptionViewItem & option , const QModelIndex & index ) const**

        Reimplements: **QAbstractItemDelegate::sizeHint(const
        QStyleOptionViewItem &option, const QModelIndex &index) const** .

        Returns the size needed by the delegate to display the item specified by
        **index** , taking into account the style information provided by
        **option**.

        This function uses the view's **QStyle**  to determine the size of the
        item.

        **See also** **QStyle::sizeFromContents** () and
        **QStyle::CT_ItemViewItem** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstyleditemdelegate.html#paint

        **[override virtual] void QStyledItemDelegate::paint(QPainter * painter
        , const QStyleOptionViewItem & option , const QModelIndex & index )
        const**

        Reimplements: **QAbstractItemDelegate::paint(QPainter *painter, const
        QStyleOptionViewItem &option, const QModelIndex &index) const** .

        Renders the delegate using the given **painter** and style **option**
        for the item specified by **index**.

        This function paints the item using the view's **QStyle** .

        When reimplementing paint in a subclass. Use the **initStyleOption** ()
        to set up the **option** in the same way as the **QStyledItemDelegate**
        .

        Whenever possible, use the **option** while painting. Especially its
        **rect**  variable to decide where to draw and its **state**  to
        determine if it is enabled or selected.

        After painting, you should ensure that the painter is returned to the
        state it was supplied in when this function was called. For example, it
        may be useful to call **QPainter::save** () before painting and
        **QPainter::restore** () afterwards.

        **See also** **QItemDelegate::paint** (), **QStyle::drawControl** (),
        and **QStyle::CE_ItemViewItem** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QImageWriter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qimagewriter.html

    **Detailed Description**

    QImageWriter supports setting format specific options, such as compression
    level and quality, prior to storing the image. If you do not need such
    options, you can use **QImage::save** () or **QPixmap::save** () instead.

    To store an image, you start by constructing a QImageWriter object. Pass
    either a file name or a device pointer, and the image format to
    QImageWriter's constructor. You can then set several options, such as
    quality (by calling **setQuality** ()). **canWrite** () returns `true` if
    QImageWriter can write the image (i.e., the image format is supported and
    the device is open for writing). Call **write** () to write the image to the
    device.

    If any error occurs when writing the image, **write** () will return false.
    You can then call **error** () to find the type of error that occurred, or
    **errorString** () to get a human readable description of what went wrong.

    Call **supportedImageFormats** () for a list of formats that QImageWriter
    can write. QImageWriter supports all built-in image formats, in addition to
    any image format plugins that support writing.

    **Note:** QImageWriter assumes exclusive control over the file or device
    that is assigned. Any attempts to modify the assigned file or device during
    the lifetime of the QImageWriter object will yield undefined results. If
    immediate access to a resource is desired, the use of a scope is the
    recommended method.

    For example:

    **QString**  imagePath(**QStringLiteral** ("path/image.jpeg"));
    **QImage**  image(64, 64, **QImage** ::Format_RGB32);
    image.fill(Qt::red);
        {
            **QImageWriter**  writer(imagePath);
    writer.write(image);
        }

        **QFile** ::rename(imagePath,
    **QStringLiteral** ("path/other_image.jpeg"));

    **See also** **QImageReader** , **QImageIOHandler** , **QImageIOPlugin** ,
    and **QColorSpace** .
    """

    class ImageWriterError(enum.Enum):
        UnknownError: QImageWriter = ...
        DeviceError: QImageWriter = ...
        UnsupportedFormatError: QImageWriter = ...
        InvalidImageError: QImageWriter = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#QImageWriter

        **QImageWriter::QImageWriter()**

        Constructs an empty QImageWriter object. Before writing, you must call
        **setFormat** () to set an image format, then **setDevice** () or
        **setFileName** ().
        """
        ...

    @typing.overload
    def __init__(self, device: QtCore.QIODevice, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#QImageWriter-1

        **QImageWriter::QImageWriter(QIODevice * device , const QByteArray &
        format )**

        Constructs a QImageWriter object using the device **device** and image
        format **format**.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, format: QtCore.QByteArray = ...) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#QImageWriter-2

        **QImageWriter::QImageWriter(const QString & fileName , const QByteArray
        & format = QByteArray())**

        Constructs a QImageWriter objects that will write to a file with the
        name **fileName** , using the image format **format**. If **format** is
        not provided, QImageWriter will detect the image format by inspecting
        the extension of **fileName**.
        """
        ...

    @staticmethod
    def imageFormatsForMimeType(
        mimeType: QtCore.QByteArray,
    ) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#imageFormatsForMimeType

        **[static, since 5.12] QList<QByteArray>
        QImageWriter::imageFormatsForMimeType(const QByteArray & mimeType )**

        Returns the list of image formats corresponding to **mimeType**.

        Note that the **QGuiApplication**  instance must be created before this
        function is called.

        This function was introduced in Qt 5.12.

        **See also** **supportedImageFormats** () and **supportedMimeTypes** ().
        """
        ...

    def setTransformation(self, orientation: QImageIOHandler.Transformation) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setTransformation

        **[since 5.5] void
        QImageWriter::setTransformation(QImageIOHandler::Transformations
        transform )**

        Sets the image transformations metadata including orientation to
        **transform**.

        If transformation metadata is not supported by the image format, the
        transform is applied before writing.

        This function was introduced in Qt 5.5.

        **See also** **transformation** () and **write** ().
        """
        ...

    def transformation(self) -> QImageIOHandler.Transformation:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#transformation

        **[since 5.5] QImageIOHandler::Transformations
        QImageWriter::transformation() const**

        Returns the transformation and orientation the image has been set to
        written with.

        This function was introduced in Qt 5.5.

        **See also** **setTransformation** ().
        """
        ...

    def progressiveScanWrite(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#progressiveScanWrite

        **[since 5.5] bool QImageWriter::progressiveScanWrite() const**

        Returns whether the image should be written as a progressive image.

        This function was introduced in Qt 5.5.

        **See also** **setProgressiveScanWrite** ().
        """
        ...

    def setProgressiveScanWrite(self, progressive: bool) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setProgressiveScanWrite

        **[since 5.5] void QImageWriter::setProgressiveScanWrite(bool
        progressive )**

        This is an image format-specific function which turns on **progressive**
        scanning when writing images. For image formats that do not support
        setting a **progressive** scan flag, this value is ignored.

        The default is false.

        This function was introduced in Qt 5.5.

        **See also** **progressiveScanWrite** ().
        """
        ...

    def optimizedWrite(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#optimizedWrite

        **[since 5.5] bool QImageWriter::optimizedWrite() const**

        Returns whether optimization has been turned on for writing the image.

        This function was introduced in Qt 5.5.

        **See also** **setOptimizedWrite** ().
        """
        ...

    def setOptimizedWrite(self, optimize: bool) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setOptimizedWrite

        **[since 5.5] void QImageWriter::setOptimizedWrite(bool optimize )**

        This is an image format-specific function which sets the **optimize**
        flags when writing images. For image formats that do not support setting
        an **optimize** flag, this value is ignored.

        The default is false.

        This function was introduced in Qt 5.5.

        **See also** **optimizedWrite** ().
        """
        ...

    def supportedSubTypes(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#supportedSubTypes

        **[since 5.4] QList<QByteArray> QImageWriter::supportedSubTypes()
        const**

        Returns the list of subtypes supported by an image.

        This function was introduced in Qt 5.4.
        """
        ...

    def subType(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#subType

        **[since 5.4] QByteArray QImageWriter::subType() const**

        Returns the subtype of the image.

        This function was introduced in Qt 5.4.

        **See also** **setSubType** ().
        """
        ...

    def setSubType(self, type: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setSubType

        **[since 5.4] void QImageWriter::setSubType(const QByteArray & type )**

        This is an image format specific function that sets the subtype of the
        image to **type**. Subtype can be used by a handler to determine which
        format it should use while saving the image.

        For example, saving an image in DDS format with A8R8G8R8 subtype:

        **QImageWriter**  writer("some/image.dds");
            if
        (writer.supportsOption(**QImageIOHandler** ::SubType))
        writer.setSubType("A8R8G8B8");
            writer.write(image);

        This function was introduced in Qt 5.4.

        **See also** **subType** ().
        """
        ...

    @staticmethod
    def supportedMimeTypes() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#supportedMimeTypes

        **[static] QList<QByteArray> QImageWriter::supportedMimeTypes()**

        Returns the list of MIME types supported by **QImageWriter** .

        Note that the **QApplication**  instance must be created before this
        function is called.

        **See also** **supportedImageFormats** () and
        **QImageReader::supportedMimeTypes** ().
        """
        ...

    def compression(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#compression

        **int QImageWriter::compression() const**

        Returns the compression of the image.

        **See also** **setCompression** ().
        """
        ...

    def setCompression(self, compression: int) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setCompression

        **void QImageWriter::setCompression(int compression )**

        This is an image format specific function that set the compression of an
        image. For image formats that do not support setting the compression,
        this value is ignored.

        The value range of **compression** depends on the image format. For
        example, the "tiff" format supports two values, 0(no compression) and
        1(LZW-compression).

        **See also** **compression** ().
        """
        ...

    def supportsOption(self, option: QImageIOHandler.ImageOption) -> bool:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#supportsOption

        **bool QImageWriter::supportsOption(QImageIOHandler::ImageOption option
        ) const**

        Returns `true` if the writer supports **option** ; otherwise returns
        false.

        Different image formats support different options. Call this function to
        determine whether a certain option is supported by the current format.
        For example, the PNG format allows you to embed text into the image's
        metadata (see text()).

        **QImageWriter**  writer(fileName);
            if
        (writer.supportsOption(**QImageIOHandler** ::Description))
        writer.setText("Author", "John Smith");

        Options can be tested after the writer has been associated with a
        format.

        **See also** **QImageReader::supportsOption** () and **setFormat** ().
        """
        ...

    def setText(self, key: str, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setText

        **void QImageWriter::setText(const QString & key , const QString & text
        )**

        Sets the image text associated with the key **key** to **text**. This is
        useful for storing copyright information or other information about the
        image. Example:

        **QImage**  image("some/image.jpeg");
            **QImageWriter**
        writer("images/outimage.png", "png");
            writer.setText("Author", "John
        Smith");
            writer.write(image);

        If you want to store a single block of data (e.g., a comment), you can
        pass an empty key, or use a generic key like "Description".

        The key and text will be embedded into the image data after calling
        **write** ().

        Support for this option is implemented through
        **QImageIOHandler::Description** .

        **See also** **QImage::setText** () and **QImageReader::text** ().
        """
        ...

    @staticmethod
    def supportedImageFormats() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#supportedImageFormats

        **[static] QList<QByteArray> QImageWriter::supportedImageFormats()**

        Returns the list of image formats supported by **QImageWriter** .

        By default, Qt can write the following formats:

        FormatMIME typeDescription
        BMPimage/bmpWindows Bitmap
        JPGimage/jpegJoint Photographic Experts Group
        PNGimage/pngPortable
        Network Graphics
        PBMimage/x-portable-bitmapPortable Bitmap
        PGMimage/x-portable-graymapPortable Graymap
        PPMimage/x-portable-
        pixmapPortable Pixmap
        XBMimage/x-xbitmapX11 Bitmap
        XPMimage/x-xpixmapX11 Pixmap

        Reading and writing SVG files is supported through the **Qt SVG**
        module. The **Qt Image Formats**  module provides support for additional
        image formats.

        Note that the **QApplication**  instance must be created before this
        function is called.

        **See also** **setFormat** (), **QImageReader::supportedImageFormats**
        (), and **QImageIOPlugin** .
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#errorString

        **QString QImageWriter::errorString() const**

        Returns a human readable description of the last error that occurred.

        **See also** **error** ().
        """
        ...

    def error(self) -> "QImageWriter.ImageWriterError":
        """
        https://doc.qt.io/qt-6/qimagewriter.html#error

        **QImageWriter::ImageWriterError QImageWriter::error() const**

        Returns the type of error that last occurred.

        **See also** **ImageWriterError**  and **errorString** ().
        """
        ...

    def write(self, image: QImage) -> bool:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#write

        **bool QImageWriter::write(const QImage & image )**

        Writes the image **image** to the assigned device or file name. Returns
        `true` on success; otherwise returns `false`. If the operation fails,
        you can call **error** () to find the type of error that occurred, or
        **errorString** () to get a human readable description of the error.

        **See also** **canWrite** (), **error** (), and **errorString** ().
        """
        ...

    def canWrite(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#canWrite

        **bool QImageWriter::canWrite() const**

        Returns `true` if **QImageWriter**  can write the image; i.e., the image
        format is supported and the assigned device is open for reading.

        **See also** **write** (), **setDevice** (), and **setFormat** ().
        """
        ...

    def quality(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#quality

        **int QImageWriter::quality() const**

        Returns the quality setting of the image format.

        **See also** **setQuality** ().
        """
        ...

    def setQuality(self, quality: int) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setQuality

        **void QImageWriter::setQuality(int quality )**

        Sets the quality setting of the image format to **quality**.

        Some image formats, in particular lossy ones, entail a tradeoff between
        a) visual quality of the resulting image, and b) encoding execution time
        and compression level. This function sets the level of that tradeoff for
        image formats that support it. For other formats, this value is ignored.

        The value range of **quality** depends on the image format. For example,
        the "jpeg" format supports a quality range from 0 (low visual quality,
        high compression) to 100 (high visual quality, low compression).

        **See also** **quality** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#fileName

        **QString QImageWriter::fileName() const**

        If the currently assigned device is a file, or if **setFileName** () has
        been called, this function returns the name of the file **QImageWriter**
        writes to. Otherwise (i.e., if no device has been assigned or the device
        is not a file), an empty **QString**  is returned.

        **See also** **setFileName** () and **setDevice** ().
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setFileName

        **void QImageWriter::setFileName(const QString & fileName )**

        Sets the file name of **QImageWriter**  to **fileName**. Internally,
        **QImageWriter**  will create a **QFile**  and open it in
        **QIODevice::WriteOnly**  mode, and use this file when writing images.

        **See also** **fileName** () and **setDevice** ().
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#device

        **QIODevice *QImageWriter::device() const**

        Returns the device currently assigned to **QImageWriter** , or `nullptr`
        if no device has been assigned.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setDevice

        **void QImageWriter::setDevice(QIODevice * device )**

        Sets **QImageWriter** 's device to **device**. If a device has already
        been set, the old device is removed from **QImageWriter**  and is
        otherwise left unchanged.

        If the device is not already open, **QImageWriter**  will attempt to
        open the device in **QIODevice::WriteOnly**  mode by calling open().
        Note that this does not work for certain devices, such as **QProcess** ,
        **QTcpSocket**  and **QUdpSocket** , where more logic is required to
        open the device.

        **See also** **device** () and **setFileName** ().
        """
        ...

    def format(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#format

        **QByteArray QImageWriter::format() const**

        Returns the format **QImageWriter**  uses for writing images.

        **See also** **setFormat** ().
        """
        ...

    def setFormat(self, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qimagewriter.html#setFormat

        **void QImageWriter::setFormat(const QByteArray & format )**

        Sets the format **QImageWriter**  will use when writing images, to
        **format**. **format** is a case insensitive text string. Example:

        **QImageWriter**  writer;
            writer.setFormat("png"); // same as
        writer.setFormat("PNG");

        You can call **supportedImageFormats** () for the full list of formats
        **QImageWriter**  supports.

        **See also** **format** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QReadWriteLock(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qreadwritelock.html

    **Detailed Description**

    A read-write lock is a synchronization tool for protecting resources that
    can be accessed for reading and writing. This type of lock is useful if you
    want to allow multiple threads to have simultaneous read-only access, but as
    soon as one thread wants to write to the resource, all other threads must be
    blocked until the writing is complete.

    In many cases, QReadWriteLock is a direct competitor to **QMutex** .
    QReadWriteLock is a good choice if there are many concurrent reads and
    writing occurs infrequently.

    Example:

    **QReadWriteLock**  lock;

        void ReaderThread::run()
        {
    ...
            lock.lockForRead();
            read_file();
            lock.unlock();
    ...
        }

        void WriterThread::run()
        {
            ...
    lock.lockForWrite();
            write_file();
            lock.unlock();
    ...
        }

    To ensure that writers aren't blocked forever by readers, readers attempting
    to obtain a lock will not succeed if there is a blocked writer waiting for
    access, even if the lock is currently only accessed by other readers. Also,
    if the lock is accessed by a writer and another writer comes in, that writer
    will have priority over any readers that might also be waiting.

    Like **QMutex** , a QReadWriteLock can be recursively locked by the same
    thread when constructed with **QReadWriteLock::Recursive**  as
    **QReadWriteLock::RecursionMode** . In such cases, **unlock** () must be
    called the same number of times **lockForWrite** () or **lockForRead** ()
    was called. Note that the lock type cannot be changed when trying to lock
    recursively, i.e. it is not possible to lock for reading in a thread that
    already has locked for writing (and vice versa).

    **See also** **QReadLocker** , **QWriteLocker** , **QMutex** , and
    **QSemaphore** .
    """

    class RecursionMode(enum.Enum):
        NonRecursive: QReadWriteLock = ...
        Recursive: QReadWriteLock = ...

    def __init__(self, recursionMode: "QReadWriteLock.RecursionMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#QReadWriteLock

        **QReadWriteLock::QReadWriteLock(QReadWriteLock::RecursionMode
        recursionMode = NonRecursive)**

        Constructs a QReadWriteLock object in the given **recursionMode**.

        The default recursion mode is **NonRecursive** .

        **See also** **lockForRead** (), **lockForWrite** (), and
        **RecursionMode** .
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#unlock

        **void QReadWriteLock::unlock()**

        Unlocks the lock.

        Attempting to unlock a lock that is not locked is an error, and will
        result in program termination.

        **See also** **lockForRead** (), **lockForWrite** (), **tryLockForRead**
        (), and **tryLockForWrite** ().
        """
        ...

    @typing.overload
    def tryLockForWrite(self) -> bool:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#tryLockForWrite

        **bool QReadWriteLock::tryLockForWrite()**

        Attempts to lock for writing. If the lock was obtained, this function
        returns `true`; otherwise, it returns `false` immediately.

        The lock attempt will fail if another thread has locked for reading or
        writing.

        If the lock was obtained, the lock must be unlocked with **unlock** ()
        before another thread can successfully lock it.

        It is not possible to lock for write if the thread already has locked
        for read.

        **See also** **unlock** () and **lockForWrite** ().
        """
        ...

    @typing.overload
    def tryLockForWrite(self, timeout: int) -> bool:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#tryLockForWrite-1

        **bool QReadWriteLock::tryLockForWrite(int timeout )**

        This is an overloaded function.

        Attempts to lock for writing. This function returns `true` if the lock
        was obtained; otherwise it returns `false`. If another thread has locked
        for reading or writing, this function will wait for at most **timeout**
        milliseconds for the lock to become available.

        Note: Passing a negative number as the **timeout** is equivalent to
        calling **lockForWrite** (), i.e. this function will wait forever until
        lock can be locked for writing when **timeout** is negative.

        If the lock was obtained, the lock must be unlocked with **unlock** ()
        before another thread can successfully lock it.

        It is not possible to lock for write if the thread already has locked
        for read.

        **See also** **unlock** () and **lockForWrite** ().
        """
        ...

    def lockForWrite(self) -> None:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#lockForWrite

        **void QReadWriteLock::lockForWrite()**

        Locks the lock for writing. This function will block the current thread
        if another thread (including the current) has locked for reading or
        writing (unless the lock has been created using the
        **QReadWriteLock::Recursive**  mode).

        It is not possible to lock for write if the thread already has locked
        for read.

        **See also** **unlock** (), **lockForRead** (), and **tryLockForWrite**
        ().
        """
        ...

    @typing.overload
    def tryLockForRead(self) -> bool:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#tryLockForRead

        **bool QReadWriteLock::tryLockForRead()**

        Attempts to lock for reading. If the lock was obtained, this function
        returns `true`, otherwise it returns `false` instead of waiting for the
        lock to become available, i.e. it does not block.

        The lock attempt will fail if another thread has locked for writing.

        If the lock was obtained, the lock must be unlocked with **unlock** ()
        before another thread can successfully lock it for writing.

        It is not possible to lock for read if the thread already has locked for
        write.

        **See also** **unlock** () and **lockForRead** ().
        """
        ...

    @typing.overload
    def tryLockForRead(self, timeout: int) -> bool:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#tryLockForRead-1

        **bool QReadWriteLock::tryLockForRead(int timeout )**

        This is an overloaded function.

        Attempts to lock for reading. This function returns `true` if the lock
        was obtained; otherwise it returns `false`. If another thread has locked
        for writing, this function will wait for at most **timeout**
        milliseconds for the lock to become available.

        Note: Passing a negative number as the **timeout** is equivalent to
        calling **lockForRead** (), i.e. this function will wait forever until
        lock can be locked for reading when **timeout** is negative.

        If the lock was obtained, the lock must be unlocked with **unlock** ()
        before another thread can successfully lock it for writing.

        It is not possible to lock for read if the thread already has locked for
        write.

        **See also** **unlock** () and **lockForRead** ().
        """
        ...

    def lockForRead(self) -> None:
        """
        https://doc.qt.io/qt-6/qreadwritelock.html#lockForRead

        **void QReadWriteLock::lockForRead()**

        Locks the lock for reading. This function will block the current thread
        if another thread has locked for writing.

        It is not possible to lock for read if the thread already has locked for
        write.

        **See also** **unlock** (), **lockForWrite** (), and **tryLockForRead**
        ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QPauseAnimation(QAbstractAnimation):
    """
    https://doc.qt.io/qt-6/qpauseanimation.html

    **Detailed Description**

    If you wish to introduce a delay between animations in a
    **QSequentialAnimationGroup** , you can insert a QPauseAnimation. This class
    does not animate anything, but does not **finish**  before a specified
    number of milliseconds have elapsed from when it was started. You specify
    the duration of the pause in the constructor. It can also be set directly
    with **setDuration** ().

    It is not necessary to construct a QPauseAnimation yourself.
    **QSequentialAnimationGroup**  provides the convenience functions
    **addPause** () and **insertPause** (). These functions simply take the
    number of milliseconds the pause should last.

    **See also** **QSequentialAnimationGroup** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpauseanimation.html#QPauseAnimation

        **QPauseAnimation::QPauseAnimation(QObject * parent = nullptr)**

        Constructs a QPauseAnimation. **parent** is passed to **QObject** 's
        constructor. The default duration is 0.
        """
        ...

    @typing.overload
    def __init__(self, msecs: int, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpauseanimation.html#QPauseAnimation-1

        **QPauseAnimation::QPauseAnimation(int msecs , QObject * parent =
        nullptr)**

        Constructs a QPauseAnimation. **msecs** is the duration of the pause.
        **parent** is passed to **QObject** 's constructor.
        """
        ...

    def updateCurrentTime(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qpauseanimation.html#updateCurrentTime

        **[override virtual protected] void
        QPauseAnimation::updateCurrentTime(int)**

        Reimplements: **QAbstractAnimation::updateCurrentTime** (int
        currentTime).
        """
        ...

    def event(self, e: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qpauseanimation.html#event

        **[override virtual protected] bool QPauseAnimation::event(QEvent * e
        )**

        Reimplements: **QAbstractAnimation::event** (QEvent *event).
        """
        ...

    def setDuration(self, msecs: int) -> None:
        """
        https://doc.qt.io/qt-6/qpauseanimation.html#duration-prop

        **[bindable] duration : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the duration of the pause.

        The duration of the pause. The duration should not be negative. The
        default duration is 250 milliseconds.

        **Member Function Documentation**
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qpauseanimation.html#duration-prop

        **[bindable] duration : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the duration of the pause.

        The duration of the pause. The duration should not be negative. The
        default duration is 250 milliseconds.

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QFontMetricsF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qfontmetricsf.html

    **Detailed Description**

    QFontMetricsF functions calculate the size of characters and strings for a
    given font. You can construct a QFontMetricsF object with an existing
    **QFont**  to obtain metrics for that font. If the font is changed later,
    the font metrics object is **not** updated.

    Once created, the object provides functions to access the individual metrics
    of the font, its characters, and for strings rendered in the font.

    There are several functions that operate on the font: **ascent** (),
    **descent** (), **height** (), **leading** () and **lineSpacing** () return
    the basic size properties of the font. The **underlinePos** (),
    **overlinePos** (), **strikeOutPos** () and **lineWidth** () functions,
    return the properties of the line that underlines, overlines or strikes out
    the characters. These functions are all fast.

    There are also some functions that operate on the set of glyphs in the font:
    **minLeftBearing** (), **minRightBearing** () and **maxWidth** (). These are
    by necessity slow, and we recommend avoiding them if possible.

    For each character, you can get its **horizontalAdvance** (),
    **leftBearing** (), and **rightBearing** (), and find out whether it is in
    the font using **inFont** (). You can also treat the character as a string,
    and use the string functions on it.

    The string functions include **horizontalAdvance** (), to return the width
    of a string in pixels (or points, for a printer), **boundingRect** (), to
    return a rectangle large enough to contain the rendered string, and **size**
    (), to return the size of that rectangle.

    Example:

    **QFont**  font("times", 24);
        **QFontMetricsF**  fm(font);
        **qreal**
    pixelsWide = fm.horizontalAdvance("What's the width of this text?");
    **qreal**  pixelsHigh = fm.height();

    **See also** **QFont** , **QFontInfo** , and **QFontDatabase** .
    """

    @typing.overload
    def __init__(self, a0: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#QFontMetricsF

        **QFontMetricsF::QFontMetricsF(const QFont & font )**

        Constructs a font metrics object for **font**.

        The font metrics will be compatible with the paintdevice used to create
        **font**.

        The font metrics object holds the information for the font that is
        passed in the constructor at the time it is created, and is not updated
        if the font's attributes are changed later.

        Use QFontMetricsF(const **QFont**  &, **QPaintDevice**  *) to get the
        font metrics that are compatible with a certain paint device.
        """
        ...

    @typing.overload
    def __init__(self, font: QFont, pd: QPaintDevice) -> None:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#QFontMetricsF-1

        **[since 5.13] QFontMetricsF::QFontMetricsF(const QFont & font , const
        QPaintDevice * paintdevice )**

        Constructs a font metrics object for **font** and **paintdevice**.

        The font metrics will be compatible with the paintdevice passed. If the
        **paintdevice** is `nullptr`, the metrics will be screen-compatible, ie.
        the metrics you get if you use the font for drawing text on a
        **widgets**  or **pixmaps** , not on a **QPicture**  or **QPrinter** .

        The font metrics object holds the information for the font that is
        passed in the constructor at the time it is created, and is not updated
        if the font's attributes are changed later.

        This function was introduced in Qt 5.13.
        """
        ...

    @typing.overload
    def __init__(self, a0: QFontMetrics) -> None:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#QFontMetricsF-2

        **QFontMetricsF::QFontMetricsF(const QFontMetrics & fontMetrics )**

        Constructs a font metrics object with floating point precision from the
        given **fontMetrics** object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QFontMetricsF") -> None:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#QFontMetricsF-3

        **QFontMetricsF::QFontMetricsF(const QFontMetricsF & fm )**

        Constructs a copy of **fm**.
        """
        ...

    def fontDpi(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#fontDpi

        **[since 5.14] qreal QFontMetricsF::fontDpi() const**

        Returns the font DPI.

        This function was introduced in Qt 5.14.
        """
        ...

    def horizontalAdvance(self, string: str, length: int = ...) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#horizontalAdvance

        **[since 5.11] qreal QFontMetricsF::horizontalAdvance(const QString &
        text , int length = -1) const**

        Returns the horizontal advance in pixels of the first **length**
        characters of **text**. If **length** is negative (the default), the
        entire string is used.

        The advance is the distance appropriate for drawing a subsequent
        character after **text**.

        This function was introduced in Qt 5.11.

        **See also** **boundingRect** ().
        """
        ...

    def capHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#capHeight

        **[since 5.8] qreal QFontMetricsF::capHeight() const**

        Returns the cap height of the font.

        The cap height of a font is the height of a capital letter above the
        baseline. It specifically is the height of capital letters that are flat
        - such as H or I - as opposed to round letters such as O, or pointed
        letters like A, both of which may display overshoot.

        This function was introduced in Qt 5.8.

        **See also** **ascent** ().
        """
        ...

    def swap(self, other: "QFontMetricsF") -> None:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#swap

        **[since 5.0] void QFontMetricsF::swap(QFontMetricsF & other )**

        Swaps this font metrics instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def inFontUcs4(self, character: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#inFontUcs4

        **bool QFontMetricsF::inFontUcs4(uint ch ) const**

        Returns `true` if the character given by **ch** , encoded in
        UCS-4/UTF-32, is a valid character in the font; otherwise returns
        `false`.
        """
        ...

    def tightBoundingRect(self, text: str) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#tightBoundingRect

        **QRectF QFontMetricsF::tightBoundingRect(const QString & text ) const**

        Returns a tight bounding rectangle around the characters in the string
        specified by **text**. The bounding rectangle always covers at least the
        set of pixels the text would cover if drawn at (0, 0).

        Note that the bounding rectangle may extend to the left of (0, 0), e.g.
        for italicized fonts, and that the width of the returned rectangle might
        be different than what the **horizontalAdvance** () method returns.

        If you want to know the advance width of the string (to lay out a set of
        strings next to each other), use **horizontalAdvance** () instead.

        Newline characters are processed as normal characters, **not** as
        linebreaks.

        **Warning:** Calling this method is very slow on Windows.

        **See also** **horizontalAdvance** (), **height** (), and
        **boundingRect** ().
        """
        ...

    def elidedText(
        self, text: str, mode: QtCore.Qt.TextElideMode, width: float, flags: int = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#elidedText

        **QString QFontMetricsF::elidedText(const QString & text ,
        Qt::TextElideMode mode , qreal width , int flags = 0) const**

        If the string **text** is wider than **width** , returns an elided
        version of the string (i.e., a string with "..." in it). Otherwise,
        returns the original string.

        The **mode** parameter specifies whether the text is elided on the left
        (for example, "...tech"), in the middle (for example, "Tr...ch"), or on
        the right (for example, "Trol...").

        The **width** is specified in pixels, not characters.

        The **flags** argument is optional and currently only supports
        **Qt::TextShowMnemonic**  as value.

        The elide mark follows the **layoutdirection** . For example, it will be
        on the right side of the text for right-to-left layouts if the **mode**
        is `Qt::ElideLeft`, and on the left side of the text if the **mode** is
        `Qt::ElideRight`.
        """
        ...

    def averageCharWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#averageCharWidth

        **qreal QFontMetricsF::averageCharWidth() const**

        Returns the average width of glyphs in the font.
        """
        ...

    def lineWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#lineWidth

        **qreal QFontMetricsF::lineWidth() const**

        Returns the width of the underline and strikeout lines, adjusted for the
        point size of the font.

        **See also** **underlinePos** (), **overlinePos** (), and
        **strikeOutPos** ().
        """
        ...

    def strikeOutPos(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#strikeOutPos

        **qreal QFontMetricsF::strikeOutPos() const**

        Returns the distance from the base line to where the strikeout line
        should be drawn.

        **See also** **underlinePos** (), **overlinePos** (), and **lineWidth**
        ().
        """
        ...

    def overlinePos(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#overlinePos

        **qreal QFontMetricsF::overlinePos() const**

        Returns the distance from the base line to where an overline should be
        drawn.

        **See also** **underlinePos** (), **strikeOutPos** (), and **lineWidth**
        ().
        """
        ...

    def underlinePos(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#underlinePos

        **qreal QFontMetricsF::underlinePos() const**

        Returns the distance from the base line to where an underscore should be
        drawn.

        **See also** **overlinePos** (), **strikeOutPos** (), and **lineWidth**
        ().
        """
        ...

    def size(
        self,
        flags: int,
        text: str,
        tabStops: int = ...,
        tabArray: typing.Optional[typing.Optional[typing.List[int]]] = ...,
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#size

        **QSizeF QFontMetricsF::size(int flags , const QString & text , int
        tabStops = 0, int * tabArray = nullptr) const**

        Returns the size in pixels of the characters in the given **text**.

        The **flags** argument is the bitwise OR of the following flags:

        * **Qt::TextSingleLine**  ignores newline characters.
          *
        **Qt::TextExpandTabs**  expands tabs (see below)
          *
        **Qt::TextShowMnemonic**  interprets "&x" as **x** ; i.e., underlined.
        * **Qt::TextWordWrap**  breaks the text to fit the rectangle.

        These flags are defined in the **Qt::TextFlag**  enum.

        If **Qt::TextExpandTabs**  is set in **flags** , the following behavior
        is used to interpret tab characters in the text:

        * If **tabArray** is non-null, it specifies a 0-terminated sequence of
        pixel-positions for tabs in the text.
          * If **tabStops** is non-zero,
        it is used as the tab spacing (in pixels).

        Newline characters are processed as line breaks.

        Note: Despite the different actual character heights, the heights of the
        bounding rectangles of "Yes" and "yes" are the same.

        **See also** **boundingRect** ().
        """
        ...

    @typing.overload
    def boundingRect(self, string: str) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#boundingRect

        **QRectF QFontMetricsF::boundingRect(const QString & text ) const**

        Returns the bounding rectangle of the characters in the string specified
        by **text**. The bounding rectangle always covers at least the set of
        pixels the text would cover if drawn at (0, 0).

        Note that the bounding rectangle may extend to the left of (0, 0), e.g.
        for italicized fonts, and that the width of the returned rectangle might
        be different than what the **horizontalAdvance** () method returns.

        If you want to know the advance width of the string (to lay out a set of
        strings next to each other), use **horizontalAdvance** () instead.

        Newline characters are processed as normal characters, **not** as
        linebreaks.

        The height of the bounding rectangle is at least as large as the value
        returned **height** ().

        **See also** **horizontalAdvance** (), **height** (), and
        **QPainter::boundingRect** ().
        """
        ...

    @typing.overload
    def boundingRect(
        self,
        rect: QtCore.QRectF,
        flags: int,
        text: str,
        tabStops: int = ...,
        tabArray: typing.Optional[typing.Optional[typing.List[int]]] = ...,
    ) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#boundingRect-1

        **QRectF QFontMetricsF::boundingRect(QChar ch ) const**

        Returns the bounding rectangle of the character **ch** relative to the
        left-most point on the base line.

        Note that the bounding rectangle may extend to the left of (0, 0), e.g.
        for italicized fonts, and that the text output may cover **all** pixels
        in the bounding rectangle.

        Note that the rectangle usually extends both above and below the base
        line.

        **See also** **horizontalAdvance** ().
        """
        ...

    def boundingRectChar(self, a0: str) -> QtCore.QRectF:
        ...

    def rightBearing(self, a0: str) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#rightBearing

        **qreal QFontMetricsF::rightBearing(QChar ch ) const**

        Returns the right bearing of character **ch** in the font.

        The right bearing is the left-ward distance of the right-most pixel of
        the character from the logical origin of a subsequent character. This
        value is negative if the pixels of the character extend to the right of
        the **horizontalAdvance** () of the character.

        See **horizontalAdvance** () for a graphical description of this metric.

        **See also** **leftBearing** (), **minRightBearing** (), and
        **horizontalAdvance** ().
        """
        ...

    def leftBearing(self, a0: str) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#leftBearing

        **qreal QFontMetricsF::leftBearing(QChar ch ) const**

        Returns the left bearing of character **ch** in the font.

        The left bearing is the right-ward distance of the left-most pixel of
        the character from the logical origin of the character. This value is
        negative if the pixels of the character extend to the left of the
        logical origin.

        See **horizontalAdvance** () for a graphical description of this metric.

        **See also** **rightBearing** (), **minLeftBearing** (), and
        **horizontalAdvance** ().
        """
        ...

    def inFont(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#inFont

        **bool QFontMetricsF::inFont(QChar ch ) const**

        Returns `true` if character **ch** is a valid character in the font;
        otherwise returns `false`.
        """
        ...

    def xHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#xHeight

        **qreal QFontMetricsF::xHeight() const**

        Returns the 'x' height of the font. This is often but not always the
        same as the height of the character 'x'.
        """
        ...

    def maxWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#maxWidth

        **qreal QFontMetricsF::maxWidth() const**

        Returns the width of the widest character in the font.
        """
        ...

    def minRightBearing(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#minRightBearing

        **qreal QFontMetricsF::minRightBearing() const**

        Returns the minimum right bearing of the font.

        This is the smallest **rightBearing** (char) of all characters in the
        font.

        Note that this function can be very slow if the font is large.

        **See also** **minLeftBearing** () and **rightBearing** ().
        """
        ...

    def minLeftBearing(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#minLeftBearing

        **qreal QFontMetricsF::minLeftBearing() const**

        Returns the minimum left bearing of the font.

        This is the smallest **leftBearing** (char) of all characters in the
        font.

        Note that this function can be very slow if the font is large.

        **See also** **minRightBearing** () and **leftBearing** ().
        """
        ...

    def lineSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#lineSpacing

        **qreal QFontMetricsF::lineSpacing() const**

        Returns the distance from one base line to the next.

        This value is always equal to **leading** ()+**height** ().

        **See also** **height** () and **leading** ().
        """
        ...

    def leading(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#leading

        **qreal QFontMetricsF::leading() const**

        Returns the leading of the font.

        This is the natural inter-line spacing.

        **See also** **height** () and **lineSpacing** ().
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#height

        **qreal QFontMetricsF::height() const**

        Returns the height of the font.

        This is always equal to **ascent** ()+**descent** ().

        **See also** **leading** () and **lineSpacing** ().
        """
        ...

    def descent(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#descent

        **qreal QFontMetricsF::descent() const**

        Returns the descent of the font.

        The descent is the distance from the base line to the lowest point
        characters extend to. (Note that this is different from X, which adds 1
        pixel.) In practice, some font designers break this rule, e.g. to
        accommodate a certain character, so it is possible (though rare) that
        this value will be too small.

        **See also** **ascent** ().
        """
        ...

    def ascent(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetricsf.html#ascent

        **qreal QFontMetricsF::ascent() const**

        Returns the ascent of the font.

        The ascent of a font is the distance from the baseline to the highest
        position characters extend to. In practice, some font designers break
        this rule, e.g. when they put more than one accent on top of a
        character, or to accommodate a certain character, so it is possible
        (though rare) that this value will be too small.

        **See also** **descent** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QRegularExpressionMatchIterator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html

    **Detailed Description**

    A QRegularExpressionMatchIterator object is a forward only Java-like
    iterator; it can be obtained by calling the
    **QRegularExpression::globalMatch** () function. A new
    QRegularExpressionMatchIterator will be positioned before the first result.
    You can then call the **hasNext** () function to check if there are more
    results available; if so, the **next** () function will return the next
    result and advance the iterator.

    Each result is a **QRegularExpressionMatch**  object holding all the
    information for that result (including captured substrings).

    For instance:

    // extracts the words
        **QRegularExpression**  re("(\\\\w+)");
    **QString**  subject("the quick fox");
    **QRegularExpressionMatchIterator**  i = re.globalMatch(subject);
        while
    (i.hasNext()) {
            **QRegularExpressionMatch**  match = i.next();
    // ...
        }

    Moreover, QRegularExpressionMatchIterator offers a **peekNext** () function
    to get the next result **without** advancing the iterator.

    Starting with Qt 6.0, it is also possible to simply use the result of
    **QRegularExpression::globalMatch**  in a range-based for loop, for instance
    like this:

    // using a raw string literal, R"(raw_characters)", to be able to use "\\w"
    // without having to escape the backslash as "\\\\w"
    **QRegularExpression**  re(R"(\\w+)");
        **QString**  subject("the quick
    fox");
        for (const **QRegularExpressionMatch**  &match :
    re.globalMatch(subject)) {
            // ...
        }

    You can retrieve the **QRegularExpression**  object the subject string was
    matched against by calling the **regularExpression** () function; the match
    type and the match options are available as well by calling the
    **matchType** () and the **matchOptions** () respectively.

    Please refer to the **QRegularExpression**  documentation for more
    information about the Qt regular expression classes.

    **See also** **QRegularExpression**  and **QRegularExpressionMatch** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#QRegularExpr
        essionMatchIterator

        **[since 5.1]
        QRegularExpressionMatchIterator::QRegularExpressionMatchIterator()**

        Constructs an empty, valid QRegularExpressionMatchIterator object. The
        regular expression is set to a default-constructed one; the match type
        to **QRegularExpression::NoMatch**  and the match options to
        **QRegularExpression::NoMatchOption** .

        Invoking the **hasNext** () member function on the constructed object
        will return false, as the iterator is not iterating on a valid sequence
        of matches.

        This function was introduced in Qt 5.1.
        """
        ...

    @typing.overload
    def __init__(self, iterator: "QRegularExpressionMatchIterator") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#QRegularExpr
        essionMatchIterator-1

        **QRegularExpressionMatchIterator::QRegularExpressionMatchIterator(const
        QRegularExpressionMatchIterator & iterator )**

        Constructs a QRegularExpressionMatchIterator object as a copy of
        **iterator**.

        **See also** **operator=** ().
        """
        ...

    def matchOptions(self) -> QRegularExpression.MatchOption:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#matchOptions

        **QRegularExpression::MatchOptions
        QRegularExpressionMatchIterator::matchOptions() const**

        Returns the match options that were used to get this
        **QRegularExpressionMatchIterator**  object, that is, the match options
        that were passed to **QRegularExpression::globalMatch** ().

        **See also** **QRegularExpression::globalMatch** (),
        **regularExpression** (), and **matchType** ().
        """
        ...

    def matchType(self) -> QRegularExpression.MatchType:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#matchType

        **QRegularExpression::MatchType
        QRegularExpressionMatchIterator::matchType() const**

        Returns the match type that was used to get this
        **QRegularExpressionMatchIterator**  object, that is, the match type
        that was passed to **QRegularExpression::globalMatch** ().

        **See also** **QRegularExpression::globalMatch** (),
        **regularExpression** (), and **matchOptions** ().
        """
        ...

    def regularExpression(self) -> QRegularExpression:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#regularExpre
        ssion

        **QRegularExpression
        QRegularExpressionMatchIterator::regularExpression() const**

        Returns the **QRegularExpression**  object whose globalMatch() function
        returned this object.

        **See also** **QRegularExpression::globalMatch** (), **matchType** (),
        and **matchOptions** ().
        """
        ...

    def peekNext(self) -> QRegularExpressionMatch:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#peekNext

        **QRegularExpressionMatch QRegularExpressionMatchIterator::peekNext()
        const**

        Returns the next match result without moving the iterator.

        **Note:** Calling this function when the iterator is at the end of the
        result set leads to undefined results.
        """
        ...

    def next(self) -> QRegularExpressionMatch:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#next

        **QRegularExpressionMatch QRegularExpressionMatchIterator::next()**

        Returns the next match result and advances the iterator by one position.

        **Note:** Calling this function when the iterator is at the end of the
        result set leads to undefined results.
        """
        ...

    def hasNext(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#hasNext

        **bool QRegularExpressionMatchIterator::hasNext() const**

        Returns `true` if there is at least one match result ahead of the
        iterator; otherwise it returns `false`.

        **See also** **next** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#isValid

        **bool QRegularExpressionMatchIterator::isValid() const**

        Returns `true` if the iterator object was obtained as a result from the
        **QRegularExpression::globalMatch** () function invoked on a valid
        **QRegularExpression**  object; returns `false` if the
        **QRegularExpression**  was invalid.

        **See also** **QRegularExpression::globalMatch** () and
        **QRegularExpression::isValid** ().
        """
        ...

    def swap(self, iterator: "QRegularExpressionMatchIterator") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatchiterator.html#swap

        **void
        QRegularExpressionMatchIterator::swap(QRegularExpressionMatchIterator &
        other )**

        Swaps the iterator **other** with this iterator object. This operation
        is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QScreen(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qscreen.html

    **Detailed Description**

    A note on logical vs physical dots per inch: physical DPI is based on the
    actual physical pixel sizes when available, and is useful for print preview
    and other cases where it's desirable to know the exact physical dimensions
    of screen displayed contents.

    Logical dots per inch are used to convert font and user interface elements
    from point sizes to pixel sizes, and might be different from the physical
    dots per inch. The logical dots per inch are sometimes user-settable in the
    desktop environment's settings panel, to let the user globally control UI
    and font sizes in different applications.

    **Note:** Both physical and logical DPI are expressed in device-independent
    dots. Multiply by **QScreen::devicePixelRatio** () to get device-dependent
    density.
    """

    def virtualSiblingAt(self, point: QtCore.QPoint) -> "QScreen":
        """
        https://doc.qt.io/qt-6/qscreen.html#virtualSiblingAt

        **[since 5.15] QScreen *QScreen::virtualSiblingAt(QPoint point )**

        Returns the screen at **point** within the set of
        **QScreen::virtualSiblings** (), or `nullptr` if outside of any screen.

        The **point** is in relation to the **virtualGeometry** () of each set
        of virtual siblings.

        This function was introduced in Qt 5.15.
        """
        ...

    def serialNumber(self) -> str:
        """
        https://doc.qt.io/qt-6/qscreen.html#serialNumber-prop

        **[read-only, since 5.9] serialNumber : const QString**

        This property holds the serial number of the screen

        This property was introduced in Qt 5.9.

        **Access functions:**

        QString **serialNumber** () const
        """
        ...

    def model(self) -> str:
        """
        https://doc.qt.io/qt-6/qscreen.html#model-prop

        **[read-only, since 5.9] model : const QString**

        This property holds the model of the screen

        This property was introduced in Qt 5.9.

        **Access functions:**

        QString **model** () const
        """
        ...

    def manufacturer(self) -> str:
        """
        https://doc.qt.io/qt-6/qscreen.html#manufacturer-prop

        **[read-only, since 5.9] manufacturer : const QString**

        This property holds the manufacturer of the screen

        This property was introduced in Qt 5.9.

        **Access functions:**

        QString **manufacturer** () const
        """
        ...

    def availableGeometryChanged(self, geometry: QtCore.QRect) -> None:
        ...

    def virtualGeometryChanged(self, rect: QtCore.QRect) -> None:
        ...

    def logicalDotsPerInchChanged(self, dpi: float) -> None:
        ...

    def physicalDotsPerInchChanged(self, dpi: float) -> None:
        ...

    def geometryChanged(self, geometry: QtCore.QRect) -> None:
        ...

    def devicePixelRatio(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#devicePixelRatio-prop

        **[read-only, since 5.5] devicePixelRatio : const qreal**

        This property holds the screen's ratio between physical pixels and
        device-independent pixels

        Returns the ratio between physical pixels and device-independent pixels
        for the screen.

        Common values are 1.0 on normal displays and 2.0 on "retina" displays.
        Higher values are also possible.

        This property was introduced in Qt 5.5.

        **Access functions:**

        qreal **devicePixelRatio** () const

        **Notifier signal:**

        void ****physicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **QWindow::devicePixelRatio** () and
        **QGuiApplication::devicePixelRatio** ().
        """
        ...

    def refreshRate(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#refreshRate-prop

        **[read-only] refreshRate : const qreal**

        This property holds the approximate vertical refresh rate of the screen
        in Hz

        **Access functions:**

        qreal **refreshRate** () const

        **Notifier signal:**

        void **refreshRateChanged** (qreal **refreshRate** )
        """
        ...

    def grabWindow(
        self,
        window: PyQt6.sip.voidptr = ...,
        x: int = ...,
        y: int = ...,
        width: int = ...,
        height: int = ...,
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qscreen.html#grabWindow

        **QPixmap QScreen::grabWindow(WId window = 0, int x = 0, int y = 0, int
        width = -1, int height = -1)**

        Creates and returns a pixmap constructed by grabbing the contents of the
        given **window** restricted by **QRect** ( **x** , **y** , **width** ,
        **height** ). If **window** is 0, then the entire screen will be
        grabbed.

        The arguments ( **x** , **y** ) specify the offset in the window,
        whereas ( **width** , **height** ) specify the area to be copied. If
        **width** is negative, the function copies everything to the right
        border of the window. If **height** is negative, the function copies
        everything to the bottom of the window.

        The offset and size arguments are specified in device independent
        pixels. The returned pixmap may be larger than the requested size when
        grabbing from a high-DPI screen. Call **QPixmap::devicePixelRatio** ()
        to determine if this is the case.

        The window system identifier (`WId`) can be retrieved using the
        **QWidget::winId** () function. The rationale for using a window
        identifier and not a **QWidget** , is to enable grabbing of windows that
        are not part of the application, window system frames, and so on.

        **Warning:** Grabbing windows that are not part of the application is
        not supported on systems such as iOS, where sandboxing/security prevents
        reading pixels of windows not owned by the application.

        The grabWindow() function grabs pixels from the screen, not from the
        window, i.e. if there is another window partially or entirely over the
        one you grab, you get pixels from the overlying window, too. The mouse
        cursor is generally not grabbed.

        Note on X11 that if the given **window** doesn't have the same depth as
        the root window, and another window partially or entirely obscures the
        one you grab, you will **not** get pixels from the overlying window. The
        contents of the obscured areas in the pixmap will be undefined and
        uninitialized.

        On Windows Vista and above grabbing a layered window, which is created
        by setting the **Qt::WA_TranslucentBackground**  attribute, will not
        work. Instead grabbing the desktop widget should work.

        **Warning:** In general, grabbing an area outside the screen is not
        safe. This depends on the underlying window system.
        """
        ...

    def isLandscape(self, orientation: QtCore.Qt.ScreenOrientation) -> bool:
        """
        https://doc.qt.io/qt-6/qscreen.html#isLandscape

        **bool QScreen::isLandscape(Qt::ScreenOrientation o ) const**

        Convenience function that returns `true` if **o** is either landscape or
        inverted landscape; otherwise returns `false`.

        **Qt::PrimaryOrientation**  is interpreted as the screen's
        **primaryOrientation** ().
        """
        ...

    def isPortrait(self, orientation: QtCore.Qt.ScreenOrientation) -> bool:
        """
        https://doc.qt.io/qt-6/qscreen.html#isPortrait

        **bool QScreen::isPortrait(Qt::ScreenOrientation o ) const**

        Convenience function that returns `true` if **o** is either portrait or
        inverted portrait; otherwise returns `false`.

        **Qt::PrimaryOrientation**  is interpreted as the screen's
        **primaryOrientation** ().
        """
        ...

    def mapBetween(
        self,
        a: QtCore.Qt.ScreenOrientation,
        b: QtCore.Qt.ScreenOrientation,
        rect: QtCore.QRect,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qscreen.html#mapBetween

        **QRect QScreen::mapBetween(Qt::ScreenOrientation a ,
        Qt::ScreenOrientation b , const QRect & rect ) const**

        Maps the rect between two screen orientations.

        This will flip the x and y dimensions of the rectangle **rect** if the
        orientation **a** is **Qt::PortraitOrientation**  or
        **Qt::InvertedPortraitOrientation**  and orientation **b** is
        **Qt::LandscapeOrientation**  or **Qt::InvertedLandscapeOrientation** ,
        or vice versa.

        **Qt::PrimaryOrientation**  is interpreted as the screen's
        **primaryOrientation** ().
        """
        ...

    def transformBetween(
        self,
        a: QtCore.Qt.ScreenOrientation,
        b: QtCore.Qt.ScreenOrientation,
        target: QtCore.QRect,
    ) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qscreen.html#transformBetween

        **QTransform QScreen::transformBetween(Qt::ScreenOrientation a ,
        Qt::ScreenOrientation b , const QRect & target ) const**

        Convenience function to compute a transform that maps from the
        coordinate system defined by orientation **a** into the coordinate
        system defined by orientation **b** and target dimensions **target**.

        Example, **a** is Qt::Landscape, **b** is Qt::Portrait, and **target**
        is **QRect** (0, 0, w, h) the resulting transform will be such that the
        point **QPoint** (0, 0) is mapped to **QPoint** (0, w), and **QPoint**
        (h, w) is mapped to **QPoint** (0, h). Thus, the landscape coordinate
        system **QRect** (0, 0, h, w) is mapped (with a 90 degree rotation) into
        the portrait coordinate system **QRect** (0, 0, w, h).

        **Qt::PrimaryOrientation**  is interpreted as the screen's
        **primaryOrientation** ().
        """
        ...

    def angleBetween(
        self, a: QtCore.Qt.ScreenOrientation, b: QtCore.Qt.ScreenOrientation
    ) -> int:
        """
        https://doc.qt.io/qt-6/qscreen.html#angleBetween

        **int QScreen::angleBetween(Qt::ScreenOrientation a ,
        Qt::ScreenOrientation b ) const**

        Convenience function to compute the angle of rotation to get from
        rotation **a** to rotation **b**.

        The result will be 0, 90, 180, or 270.

        **Qt::PrimaryOrientation**  is interpreted as the screen's
        **primaryOrientation** ().
        """
        ...

    def orientation(self) -> QtCore.Qt.ScreenOrientation:
        """
        https://doc.qt.io/qt-6/qscreen.html#orientation-prop

        **[read-only] orientation : const Qt::ScreenOrientation**

        This property holds the screen orientation

        The `orientation` property tells the orientation of the screen from the
        window system perspective.

        Most mobile devices and tablet computers contain accelerometer sensors.
        The Qt Sensors module provides the ability to read this sensor directly.
        However, the windowing system may rotate the entire screen automatically
        based on how it is being held; in that case, this `orientation` property
        will change.

        **Access functions:**

        Qt::ScreenOrientation **orientation** () const

        **Notifier signal:**

        void ****orientationChanged** ** (Qt::ScreenOrientation **orientation**
        )

        **See also** **primaryOrientation** () and
        **QWindow::contentOrientation** ().
        """
        ...

    def primaryOrientation(self) -> QtCore.Qt.ScreenOrientation:
        """
        https://doc.qt.io/qt-6/qscreen.html#primaryOrientation-prop

        **[read-only] primaryOrientation : const Qt::ScreenOrientation**

        This property holds the primary screen orientation

        The primary screen orientation is **Qt::LandscapeOrientation**  if the
        screen geometry's width is greater than or equal to its height, or
        **Qt::PortraitOrientation**  otherwise. This property might change when
        the screen orientation was changed (i.e. when the display is rotated).
        The behavior is however platform dependent and can often be specified in
        an application manifest file.

        **Access functions:**

        Qt::ScreenOrientation **primaryOrientation** () const

        **Notifier signal:**

        void ****primaryOrientationChanged** ** (Qt::ScreenOrientation
        **orientation** )
        """
        ...

    def nativeOrientation(self) -> QtCore.Qt.ScreenOrientation:
        """
        https://doc.qt.io/qt-6/qscreen.html#nativeOrientation-prop

        **[read-only, since 5.2] nativeOrientation : const
        Qt::ScreenOrientation**

        This property holds the native screen orientation

        The native orientation of the screen is the orientation where the logo
        sticker of the device appears the right way up, or
        **Qt::PrimaryOrientation**  if the platform does not support this
        functionality.

        The native orientation is a property of the hardware, and does not
        change.

        This property was introduced in Qt 5.2.

        **Access functions:**

        Qt::ScreenOrientation **nativeOrientation** () const
        """
        ...

    def availableVirtualGeometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qscreen.html#availableVirtualGeometry-prop

        **[read-only] availableVirtualGeometry : const QRect**

        This property holds the available geometry of the virtual desktop to
        which this screen belongs

        Returns the available geometry of the virtual desktop corresponding to
        this screen.

        This is the union of the virtual siblings' individual available
        geometries.

        **Access functions:**

        QRect **availableVirtualGeometry** () const

        **Notifier signal:**

        void ****virtualGeometryChanged** ** (const QRect & **rect** )

        **See also** **availableGeometry** () and **virtualSiblings** ().
        """
        ...

    def availableVirtualSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscreen.html#availableVirtualSize-prop

        **[read-only] availableVirtualSize : const QSize**

        This property holds the available size of the virtual desktop to which
        this screen belongs

        Returns the available pixel size of the virtual desktop corresponding to
        this screen.

        This is the combined size of the virtual siblings' individual available
        geometries.

        **Access functions:**

        QSize **availableVirtualSize** () const

        **Notifier signal:**

        void ****virtualGeometryChanged** ** (const QRect & **rect** )

        **See also** **availableSize** () and **virtualSiblings** ().
        """
        ...

    def virtualGeometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qscreen.html#virtualGeometry-prop

        **[read-only] virtualGeometry : const QRect**

        This property holds the pixel geometry of the virtual desktop to which
        this screen belongs

        Returns the pixel geometry of the virtual desktop corresponding to this
        screen.

        This is the union of the virtual siblings' individual geometries.

        **Access functions:**

        QRect **virtualGeometry** () const

        **Notifier signal:**

        void ****virtualGeometryChanged** ** (const QRect & **rect** )

        **See also** **virtualSiblings** ().
        """
        ...

    def virtualSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscreen.html#virtualSize-prop

        **[read-only] virtualSize : const QSize**

        This property holds the pixel size of the virtual desktop to which this
        screen belongs

        Returns the pixel size of the virtual desktop corresponding to this
        screen.

        This is the combined size of the virtual siblings' individual
        geometries.

        **Access functions:**

        QSize **virtualSize** () const

        **Notifier signal:**

        void ****virtualGeometryChanged** ** (const QRect & **rect** )

        **See also** **virtualSiblings** ().

        **Member Function Documentation**
        """
        ...

    def virtualSiblings(self) -> typing.List["QScreen"]:
        """
        https://doc.qt.io/qt-6/qscreen.html#virtualSiblings

        **QList<QScreen *> QScreen::virtualSiblings() const**

        Get the screen's virtual siblings.

        The virtual siblings are the screen instances sharing the same virtual
        desktop. They share a common coordinate system, and windows can freely
        be moved or positioned across them without having to be re-created.
        """
        ...

    def availableGeometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qscreen.html#availableGeometry-prop

        **[read-only] availableGeometry : const QRect**

        This property holds the screen's available geometry in pixels

        The available geometry is the geometry excluding window manager reserved
        areas such as task bars and system menus.

        Note, on X11 this will return the true available geometry only on
        systems with one monitor and if window manager has set _NET_WORKAREA
        atom. In all other cases this is equal to **geometry** (). This is a
        limitation in X11 window manager specification.

        **Access functions:**

        QRect **availableGeometry** () const

        **Notifier signal:**

        void ****availableGeometryChanged** ** (const QRect & **geometry** )
        """
        ...

    def availableSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscreen.html#availableSize-prop

        **[read-only] availableSize : const QSize**

        This property holds the screen's available size in pixels

        The available size is the size excluding window manager reserved areas
        such as task bars and system menus.

        **Access functions:**

        QSize **availableSize** () const

        **Notifier signal:**

        void ****availableGeometryChanged** ** (const QRect & **geometry** )
        """
        ...

    def logicalDotsPerInch(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#logicalDotsPerInch-prop

        **[read-only] logicalDotsPerInch : const qreal**

        This property holds the number of logical dots or pixels per inch

        This value can be used to convert font point sizes to pixel sizes.

        This is a convenience property that's simply the average of the
        **logicalDotsPerInchX**  and **logicalDotsPerInchY**  properties.

        **Access functions:**

        qreal **logicalDotsPerInch** () const

        **Notifier signal:**

        void ****logicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **logicalDotsPerInchX** () and **logicalDotsPerInchY** ().
        """
        ...

    def logicalDotsPerInchY(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#logicalDotsPerInchY-prop

        **[read-only] logicalDotsPerInchY : const qreal**

        This property holds the number of logical dots or pixels per inch in the
        vertical direction

        This value is used to convert font point sizes to pixel sizes.

        **Access functions:**

        qreal **logicalDotsPerInchY** () const

        **Notifier signal:**

        void ****logicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **logicalDotsPerInchX** ().
        """
        ...

    def logicalDotsPerInchX(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#logicalDotsPerInchX-prop

        **[read-only] logicalDotsPerInchX : const qreal**

        This property holds the number of logical dots or pixels per inch in the
        horizontal direction

        This value is used to convert font point sizes to pixel sizes.

        **Access functions:**

        qreal **logicalDotsPerInchX** () const

        **Notifier signal:**

        void ****logicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **logicalDotsPerInchY** ().
        """
        ...

    def physicalDotsPerInch(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#physicalDotsPerInch-prop

        **[read-only] physicalDotsPerInch : const qreal**

        This property holds the number of physical dots or pixels per inch

        This value represents the pixel density on the screen's display.
        Depending on what information the underlying system provides the value
        might not be entirely accurate.

        This is a convenience property that's simply the average of the
        **physicalDotsPerInchX**  and **physicalDotsPerInchY**  properties.

        **Note:** Physical DPI is expressed in device-independent dots. Multiply
        by **QScreen::devicePixelRatio** () to get device-dependent density.

        **Access functions:**

        qreal **physicalDotsPerInch** () const

        **Notifier signal:**

        void ****physicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **physicalDotsPerInchX** () and **physicalDotsPerInchY**
        ().
        """
        ...

    def physicalDotsPerInchY(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#physicalDotsPerInchY-prop

        **[read-only] physicalDotsPerInchY : const qreal**

        This property holds the number of physical dots or pixels per inch in
        the vertical direction

        This value represents the actual vertical pixel density on the screen's
        display. Depending on what information the underlying system provides
        the value might not be entirely accurate.

        **Note:** Physical DPI is expressed in device-independent dots. Multiply
        by **QScreen::devicePixelRatio** () to get device-dependent density.

        **Access functions:**

        qreal **physicalDotsPerInchY** () const

        **Notifier signal:**

        void ****physicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **physicalDotsPerInchX** ().
        """
        ...

    def physicalDotsPerInchX(self) -> float:
        """
        https://doc.qt.io/qt-6/qscreen.html#physicalDotsPerInchX-prop

        **[read-only] physicalDotsPerInchX : const qreal**

        This property holds the number of physical dots or pixels per inch in
        the horizontal direction

        This value represents the actual horizontal pixel density on the
        screen's display. Depending on what information the underlying system
        provides the value might not be entirely accurate.

        **Note:** Physical DPI is expressed in device-independent dots. Multiply
        by **QScreen::devicePixelRatio** () to get device-dependent density.

        **Access functions:**

        qreal **physicalDotsPerInchX** () const

        **Notifier signal:**

        void ****physicalDotsPerInchChanged** ** (qreal **dpi** )

        **See also** **physicalDotsPerInchY** ().
        """
        ...

    def physicalSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qscreen.html#physicalSize-prop

        **[read-only] physicalSize : const QSizeF**

        This property holds the screen's physical size (in millimeters)

        The physical size represents the actual physical dimensions of the
        screen's display.

        Depending on what information the underlying system provides the value
        might not be entirely accurate.

        **Access functions:**

        QSizeF **physicalSize** () const

        **Notifier signal:**

        void **physicalSizeChanged** (const QSizeF & **size** )
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qscreen.html#geometry-prop

        **[read-only] geometry : const QRect**

        This property holds the screen's geometry in pixels

        As an example this might return **QRect** (0, 0, 1280, 1024), or in a
        virtual desktop setting **QRect** (1280, 0, 1280, 1024).

        **Access functions:**

        QRect **geometry** () const

        **Notifier signal:**

        void ****geometryChanged** ** (const QRect & **geometry** )
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscreen.html#size-prop

        **[read-only] size : const QSize**

        This property holds the pixel resolution of the screen

        **Access functions:**

        QSize **size** () const

        **Notifier signal:**

        void ****geometryChanged** ** (const QRect & **geometry** )
        """
        ...

    def depth(self) -> int:
        """
        https://doc.qt.io/qt-6/qscreen.html#depth-prop

        **[read-only] depth : const int**

        This property holds the color depth of the screen

        **Access functions:**

        int **depth** () const
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qscreen.html#name-prop

        **[read-only] name : const QString**

        This property holds a user presentable string representing the screen

        For example, on X11 these correspond to the XRandr screen names,
        typically "VGA1", "HDMI1", etc.

        **Access functions:**

        QString **name** () const
        """
        ...

    @property
    def orientationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qscreen.html#orientationChanged

        **[signal] void QScreen::orientationChanged(Qt::ScreenOrientation
        orientation )**

        This signal is emitted when the orientation of the screen changes with
        **orientation** as an argument.

        **Note:** Notifier signal for property **orientation** .

        **See also** **orientation** ().
        """
        ...

    @property
    def physicalSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def primaryOrientationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qscreen.html#primaryOrientationChanged

        **[signal] void QScreen::primaryOrientationChanged(Qt::ScreenOrientation
        orientation )**

        This signal is emitted when the primary orientation of the screen
        changes with **orientation** as an argument.

        **Note:** Notifier signal for property **primaryOrientation** .

        **See also** **primaryOrientation** ().
        """
        ...

    @property
    def refreshRateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtXml import *


class QDomNodeList(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdomnodelist.html

    **Detailed Description**

    Lists can be obtained by **QDomDocument::elementsByTagName** () and
    **QDomNode::childNodes** (). The Document Object Model (DOM) requires these
    lists to be "live": whenever you change the underlying document, the
    contents of the list will get updated.

    You can get a particular node from the list with **item** (). The number of
    items in the list is returned by **length** ().

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.

    **See also** **QDomNode::childNodes** () and
    **QDomDocument::elementsByTagName** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#QDomNodeList

        **QDomNodeList::QDomNodeList()**

        Creates an empty node list.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDomNodeList") -> None:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#QDomNodeList-1

        **QDomNodeList::QDomNodeList(const QDomNodeList & n )**

        Constructs a copy of **n**.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#isEmpty

        **bool QDomNodeList::isEmpty() const**

        Returns `true` if the list contains no items; otherwise returns `false`.
        This function is provided for Qt API consistency.
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#size

        **int QDomNodeList::size() const**

        This function is provided for Qt API consistency. It is equivalent to
        **length** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#count

        **int QDomNodeList::count() const**

        This function is provided for Qt API consistency. It is equivalent to
        **length** ().
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#length

        **int QDomNodeList::length() const**

        Returns the number of nodes in the list.
        """
        ...

    def at(self, index: int) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#at

        **QDomNode QDomNodeList::at(int index ) const**

        This function is provided for Qt API consistency. It is equivalent to
        **item** ().

        If **index** is negative or if **index** >= **length** () then a null
        node is returned (i.e. a node for which **QDomNode::isNull** () returns
        true).
        """
        ...

    def item(self, index: int) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnodelist.html#item

        **QDomNode QDomNodeList::item(int index ) const**

        Returns the node at position **index**.

        If **index** is negative or if **index** >= **length** () then a null
        node is returned (i.e. a node for which **QDomNode::isNull** () returns
        true).

        **See also** **length** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QFontDatabase(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qfontdatabase.html

    **Detailed Description**

    The most common uses of this class are to query the database for the list of
    font **families** () and for the **pointSizes** () and **styles** () that
    are available for each family. An alternative to **pointSizes** () is
    **smoothSizes** () which returns the sizes at which a given family and style
    will look attractive.

    If the font family is available from two or more foundries the foundry name
    is included in the family name; for example: "Helvetica [Adobe]" and
    "Helvetica [Cronyx]". When you specify a family, you can either use the old
    hyphenated "foundry-family" format or the bracketed "family [foundry]"
    format; for example: "Cronyx-Helvetica" or "Helvetica [Cronyx]". If the
    family has a foundry it is always returned using the bracketed format, as is
    the case with the value returned by **families** ().

    The **font** () function returns a **QFont**  given a family, style and
    point size.

    A family and style combination can be checked to see if it is **italic** ()
    or **bold** (), and to retrieve its **weight** (). Similarly we can call
    **isBitmapScalable** (), **isSmoothlyScalable** (), **isScalable** () and
    **isFixedPitch** ().

    Use the **styleString** () to obtain a text version of a style.

    The QFontDatabase class provides some helper functions, for example,
    **standardSizes** (). You can retrieve the description of a writing system
    using **writingSystemName** (), and a sample of characters in a writing
    system with **writingSystemSample** ().

    Example:

    **QTreeWidget**  fontTree;
        fontTree.setColumnCount(2);
    fontTree.setHeaderLabels(**QStringList** () << "Font" << "Smooth Sizes");
    const **QStringList**  fontFamilies = **QFontDatabase** ::families();
    for (const **QString**  &family : fontFamilies) {
    **QTreeWidgetItem**  *familyItem = new **QTreeWidgetItem** (&fontTree);
    familyItem->setText(0, family);

            const **QStringList**
    fontStyles = **QFontDatabase** ::styles(family);
            for (const
    **QString**  &style : fontStyles) {
                **QTreeWidgetItem**
    *styleItem = new **QTreeWidgetItem** (familyItem);
    styleItem->setText(0, style);

                **QString**  sizes;
    const **QList** <int> smoothSizes = **QFontDatabase** ::smoothSizes(family,
    style);
                for (const auto &points : smoothSizes)
    sizes += **QString** ::number(points) + ' ';
    styleItem->setText(1, sizes.trimmed());
            }
        }

    This example gets the list of font families, the list of styles for each
    family, and the point sizes that are available for each combination of
    family and style, displaying this information in a tree view.

    **See also** **QFont** , **QFontInfo** , **QFontMetrics** , and **Character
    Map Example** .
    """

    class SystemFont(enum.Enum):
        GeneralFont: QFontDatabase = ...
        FixedFont: QFontDatabase = ...
        TitleFont: QFontDatabase = ...
        SmallestReadableFont: QFontDatabase = ...

    class WritingSystem(enum.Enum):
        Any: QFontDatabase = ...
        Latin: QFontDatabase = ...
        Greek: QFontDatabase = ...
        Cyrillic: QFontDatabase = ...
        Armenian: QFontDatabase = ...
        Hebrew: QFontDatabase = ...
        Arabic: QFontDatabase = ...
        Syriac: QFontDatabase = ...
        Thaana: QFontDatabase = ...
        Devanagari: QFontDatabase = ...
        Bengali: QFontDatabase = ...
        Gurmukhi: QFontDatabase = ...
        Gujarati: QFontDatabase = ...
        Oriya: QFontDatabase = ...
        Tamil: QFontDatabase = ...
        Telugu: QFontDatabase = ...
        Kannada: QFontDatabase = ...
        Malayalam: QFontDatabase = ...
        Sinhala: QFontDatabase = ...
        Thai: QFontDatabase = ...
        Lao: QFontDatabase = ...
        Tibetan: QFontDatabase = ...
        Myanmar: QFontDatabase = ...
        Georgian: QFontDatabase = ...
        Khmer: QFontDatabase = ...
        SimplifiedChinese: QFontDatabase = ...
        TraditionalChinese: QFontDatabase = ...
        Japanese: QFontDatabase = ...
        Korean: QFontDatabase = ...
        Vietnamese: QFontDatabase = ...
        Other: QFontDatabase = ...
        Symbol: QFontDatabase = ...
        Ogham: QFontDatabase = ...
        Runic: QFontDatabase = ...
        Nko: QFontDatabase = ...

    def __init__(self, a0: "QFontDatabase") -> None:
        ...

    @staticmethod
    def isPrivateFamily(family: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#isPrivateFamily

        **[static, since 5.5] bool QFontDatabase::isPrivateFamily(const QString
        & family )**

        Returns `true` if and only if the **family** font family is private.

        This happens, for instance, on macOS and iOS, where the system UI fonts
        are not accessible to the user. For completeness,
        **QFontDatabase::families** () returns all font families, including the
        private ones. You should use this function if you are developing a font
        selection control in order to keep private fonts hidden.

        This function was introduced in Qt 5.5.

        **See also** **families** ().
        """
        ...

    @staticmethod
    def systemFont(type: "QFontDatabase.SystemFont") -> QFont:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#systemFont

        **[static, since 5.2] QFont
        QFontDatabase::systemFont(QFontDatabase::SystemFont type )**

        Returns the most adequate font for a given **type** case for proper
        integration with the system's look and feel.

        This function was introduced in Qt 5.2.

        **See also** **QGuiApplication::font** ().
        """
        ...

    @staticmethod
    def removeAllApplicationFonts() -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#removeAllApplicationFonts

        **[static] bool QFontDatabase::removeAllApplicationFonts()**

        Removes all application-local fonts previously added using
        **addApplicationFont** () and **addApplicationFontFromData** ().

        Returns `true` if unloading of the fonts succeeded; otherwise returns
        `false`.

        **See also** **removeApplicationFont** (), **addApplicationFont** (),
        and **addApplicationFontFromData** ().
        """
        ...

    @staticmethod
    def removeApplicationFont(id: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#removeApplicationFont

        **[static] bool QFontDatabase::removeApplicationFont(int id )**

        Removes the previously loaded application font identified by **id**.
        Returns `true` if unloading of the font succeeded; otherwise returns
        `false`.

        **See also** **removeAllApplicationFonts** (), **addApplicationFont**
        (), and **addApplicationFontFromData** ().
        """
        ...

    @staticmethod
    def applicationFontFamilies(id: int) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#applicationFontFamilies

        **[static] QStringList QFontDatabase::applicationFontFamilies(int id )**

        Returns a list of font families for the given application font
        identified by **id**.

        **See also** **addApplicationFont** () and
        **addApplicationFontFromData** ().
        """
        ...

    @staticmethod
    def addApplicationFontFromData(fontData: QtCore.QByteArray) -> int:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#addApplicationFontFromData

        **[static] int QFontDatabase::addApplicationFontFromData(const
        QByteArray & fontData )**

        Loads the font from binary data specified by **fontData** and makes it
        available to the application. An ID is returned that can be used to
        remove the font again with **removeApplicationFont** () or to retrieve
        the list of family names contained in the font.

        The function returns -1 if the font could not be loaded.

        Currently only TrueType fonts and TrueType font collections are
        supported.

        **Note:** Adding application fonts on Unix/X11 platforms without
        fontconfig is currently not supported.

        **See also** **addApplicationFont** (), **applicationFontFamilies** (),
        and **removeApplicationFont** ().
        """
        ...

    @staticmethod
    def addApplicationFont(fileName: str) -> int:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#addApplicationFont

        **[static] int QFontDatabase::addApplicationFont(const QString &
        fileName )**

        Loads the font from the file specified by **fileName** and makes it
        available to the application. An ID is returned that can be used to
        remove the font again with **removeApplicationFont** () or to retrieve
        the list of family names contained in the font.

        The function returns -1 if the font could not be loaded.

        Currently only TrueType fonts, TrueType font collections, and OpenType
        fonts are supported.

        **Note:** Adding application fonts on Unix/X11 platforms without
        fontconfig is currently not supported.

        **See also** **addApplicationFontFromData** (),
        **applicationFontFamilies** (), and **removeApplicationFont** ().
        """
        ...

    @staticmethod
    def writingSystemSample(writingSystem: "QFontDatabase.WritingSystem") -> str:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#writingSystemSample

        **[static] QString
        QFontDatabase::writingSystemSample(QFontDatabase::WritingSystem
        writingSystem )**

        Returns a string with sample characters from **writingSystem**.
        """
        ...

    @staticmethod
    def writingSystemName(writingSystem: "QFontDatabase.WritingSystem") -> str:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#writingSystemName

        **[static] QString
        QFontDatabase::writingSystemName(QFontDatabase::WritingSystem
        writingSystem )**

        Returns the names the **writingSystem** (e.g. for displaying to the user
        in a dialog).
        """
        ...

    @staticmethod
    def weight(family: str, style: str) -> int:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#weight

        **[static] int QFontDatabase::weight(const QString & family , const
        QString & style )**

        Returns the weight of the font that has family **family** and style
        **style**. If there is no such family and style combination, returns -1.

        **See also** **italic** () and **bold** ().
        """
        ...

    @staticmethod
    def bold(family: str, style: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#bold

        **[static] bool QFontDatabase::bold(const QString & family , const
        QString & style )**

        Returns `true` if the font that has family **family** and style
        **style** is bold; otherwise returns `false`.

        **See also** **italic** () and **weight** ().
        """
        ...

    @staticmethod
    def italic(family: str, style: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#italic

        **[static] bool QFontDatabase::italic(const QString & family , const
        QString & style )**

        Returns `true` if the font that has family **family** and style
        **style** is italic; otherwise returns `false`.

        **See also** **weight** () and **bold** ().
        """
        ...

    @staticmethod
    def isFixedPitch(family: str, style: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#isFixedPitch

        **[static] bool QFontDatabase::isFixedPitch(const QString & family ,
        const QString & style = QString())**

        Returns `true` if the font that has family **family** and style
        **style** is fixed pitch; otherwise returns `false`.
        """
        ...

    @staticmethod
    def isScalable(family: str, style: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#isScalable

        **[static] bool QFontDatabase::isScalable(const QString & family , const
        QString & style = QString())**

        Returns `true` if the font that has family **family** and style
        **style** is scalable; otherwise returns `false`.

        **See also** **isBitmapScalable** () and **isSmoothlyScalable** ().
        """
        ...

    @staticmethod
    def isSmoothlyScalable(family: str, style: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#isSmoothlyScalable

        **[static] bool QFontDatabase::isSmoothlyScalable(const QString & family
        , const QString & style = QString())**

        Returns `true` if the font that has family **family** and style
        **style** is smoothly scalable; otherwise returns `false`. If this
        function returns `true`, it's safe to scale this font to any size, and
        the result will always look attractive.

        **See also** **isScalable** () and **isBitmapScalable** ().
        """
        ...

    @staticmethod
    def isBitmapScalable(family: str, style: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#isBitmapScalable

        **[static] bool QFontDatabase::isBitmapScalable(const QString & family ,
        const QString & style = QString())**

        Returns `true` if the font that has family **family** and style
        **style** is a scalable bitmap font; otherwise returns `false`. Scaling
        a bitmap font usually produces an unattractive hardly readable result,
        because the pixels of the font are scaled. If you need to scale a bitmap
        font it is better to scale it to one of the fixed sizes returned by
        **smoothSizes** ().

        **See also** **isScalable** () and **isSmoothlyScalable** ().
        """
        ...

    @staticmethod
    def font(family: str, style: str, pointSize: int) -> QFont:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#font

        **[static] QFont QFontDatabase::font(const QString & family , const
        QString & style , int pointSize )**

        Returns a **QFont**  object that has family **family** , style **style**
        and point size **pointSize**. If no matching font could be created, a
        **QFont**  object that uses the application's default font is returned.
        """
        ...

    @typing.overload
    @staticmethod
    def styleString(fontInfo: "QFontInfo") -> str:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#styleString

        **[static] QString QFontDatabase::styleString(const QFont & font )**

        Returns a string that describes the style of the **font**. For example,
        "Bold Italic", "Bold", "Italic" or "Normal". An empty string may be
        returned.
        """
        ...

    @typing.overload
    @staticmethod
    def styleString(font: QFont) -> str:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#styleString-1

        **[static] QString QFontDatabase::styleString(const QFontInfo & fontInfo
        )**

        Returns a string that describes the style of the **fontInfo**. For
        example, "Bold Italic", "Bold", "Italic" or "Normal". An empty string
        may be returned.
        """
        ...

    @staticmethod
    def smoothSizes(family: str, style: str) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#smoothSizes

        **[static] QList<int> QFontDatabase::smoothSizes(const QString & family
        , const QString & styleName )**

        Returns the point sizes of a font that has family **family** and style
        **styleName** that will look attractive. The list may be empty. For non-
        scalable fonts and bitmap scalable fonts, this function is equivalent to
        **pointSizes** ().

        **See also** **pointSizes** () and **standardSizes** ().
        """
        ...

    @staticmethod
    def pointSizes(family: str, style: str = ...) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#pointSizes

        **[static] QList<int> QFontDatabase::pointSizes(const QString & family ,
        const QString & styleName = QString())**

        Returns a list of the point sizes available for the font that has family
        **family** and style **styleName**. The list may be empty.

        **See also** **smoothSizes** () and **standardSizes** ().
        """
        ...

    @staticmethod
    def styles(family: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#styles

        **[static] QStringList QFontDatabase::styles(const QString & family )**

        Returns a list of the styles available for the font family **family**.
        Some example styles: "Light", "Light Italic", "Bold", "Oblique", "Demi".
        The list may be empty.

        **See also** **families** ().
        """
        ...

    @staticmethod
    def families(
        writingSystem: "QFontDatabase.WritingSystem" = ...,
    ) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#families

        **[static] QStringList
        QFontDatabase::families(QFontDatabase::WritingSystem writingSystem =
        Any)**

        Returns a sorted list of the available font families which support the
        **writingSystem**.

        If a family exists in several foundries, the returned name for that font
        is in the form "family [foundry]". Examples: "Times [Adobe]", "Times
        [Cronyx]", "Palatino".

        **See also** **writingSystems** ().
        """
        ...

    @typing.overload
    @staticmethod
    def writingSystems(family: str) -> typing.List["QFontDatabase.WritingSystem"]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#writingSystems

        **[static] QList<QFontDatabase::WritingSystem>
        QFontDatabase::writingSystems()**

        Returns a sorted list of the available writing systems. This is list
        generated from information about all installed fonts on the system.

        **See also** **families** ().
        """
        ...

    @typing.overload
    @staticmethod
    def writingSystems() -> typing.List["QFontDatabase.WritingSystem"]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#writingSystems-1

        **[static] QList<QFontDatabase::WritingSystem>
        QFontDatabase::writingSystems(const QString & family )**

        Returns a sorted list of the writing systems supported by a given font
        **family**.

        **See also** **families** ().
        """
        ...

    @staticmethod
    def standardSizes() -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qfontdatabase.html#standardSizes

        **[static] QList<int> QFontDatabase::standardSizes()**

        Returns a list of standard font sizes.

        **See also** **smoothSizes** () and **pointSizes** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QVideoFrameFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qvideoframeformat.html

    **Detailed Description**

    A video sink presents a stream of video frames. QVideoFrameFormat describes
    the type of the frames and determines how they should be presented.

    The core properties of a video stream required to setup a video sink are the
    pixel format given by **pixelFormat** (), and the frame dimensions given by
    **frameSize** ().

    The region of a frame that is actually displayed on a video surface is given
    by the **viewport** (). A stream may have a viewport less than the entire
    region of a frame to allow for videos smaller than the nearest optimal size
    of a video frame. For example the width of a frame may be extended so that
    the start of each scan line is eight byte aligned.

    Other common properties are the **scanLineDirection** (), **frameRate** ()
    and the yCrCbColorSpace().
    """

    class YCbCrColorSpace(enum.Enum):
        YCbCr_Undefined: QVideoFrameFormat = ...
        YCbCr_BT601: QVideoFrameFormat = ...
        YCbCr_BT709: QVideoFrameFormat = ...
        YCbCr_xvYCC601: QVideoFrameFormat = ...
        YCbCr_xvYCC709: QVideoFrameFormat = ...
        YCbCr_JPEG: QVideoFrameFormat = ...

    class Direction(enum.Enum):
        TopToBottom: QVideoFrameFormat = ...
        BottomToTop: QVideoFrameFormat = ...

    class PixelFormat(enum.Enum):
        Format_Invalid: QVideoFrameFormat = ...
        Format_YUV420P: QVideoFrameFormat = ...
        Format_YUV422P: QVideoFrameFormat = ...
        Format_YV12: QVideoFrameFormat = ...
        Format_UYVY: QVideoFrameFormat = ...
        Format_YUYV: QVideoFrameFormat = ...
        Format_NV12: QVideoFrameFormat = ...
        Format_NV21: QVideoFrameFormat = ...
        Format_IMC1: QVideoFrameFormat = ...
        Format_IMC2: QVideoFrameFormat = ...
        Format_IMC3: QVideoFrameFormat = ...
        Format_IMC4: QVideoFrameFormat = ...
        Format_Y8: QVideoFrameFormat = ...
        Format_Y16: QVideoFrameFormat = ...
        Format_P010: QVideoFrameFormat = ...
        Format_P016: QVideoFrameFormat = ...
        Format_Jpeg: QVideoFrameFormat = ...
        Format_SamplerExternalOES: QVideoFrameFormat = ...
        Format_ARGB8888: QVideoFrameFormat = ...
        Format_ARGB8888_Premultiplied: QVideoFrameFormat = ...
        Format_XRGB8888: QVideoFrameFormat = ...
        Format_BGRA8888: QVideoFrameFormat = ...
        Format_BGRA8888_Premultiplied: QVideoFrameFormat = ...
        Format_BGRX8888: QVideoFrameFormat = ...
        Format_ABGR8888: QVideoFrameFormat = ...
        Format_XBGR8888: QVideoFrameFormat = ...
        Format_RGBA8888: QVideoFrameFormat = ...
        Format_RGBX8888: QVideoFrameFormat = ...
        Format_AYUV: QVideoFrameFormat = ...
        Format_AYUV_Premultiplied: QVideoFrameFormat = ...
        Format_SamplerRect: QVideoFrameFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#QVideoFrameFormat

        **QVideoFrameFormat::QVideoFrameFormat()**

        Constructs a null video stream format.
        """
        ...

    @typing.overload
    def __init__(
        self, size: QtCore.QSize, pixelFormat: "QVideoFrameFormat.PixelFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#QVideoFrameFormat-1

        **QVideoFrameFormat::QVideoFrameFormat(const QSize & size ,
        QVideoFrameFormat::PixelFormat format )**

        Constructs a video stream with the given frame **size** and pixel
        **format**.
        """
        ...

    @typing.overload
    def __init__(self, format: "QVideoFrameFormat") -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#QVideoFrameFormat-2

        **QVideoFrameFormat::QVideoFrameFormat(const QVideoFrameFormat & other
        )**

        Constructs a copy of **other**.
        """
        ...

    @staticmethod
    def imageFormatFromPixelFormat(
        format: "QVideoFrameFormat.PixelFormat",
    ) -> QtGui.QImage.Format:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#imageFormatFromPixelFormat

        **[static] QImage::Format QVideoFrameFormat::imageFormatFromPixelFormat(
        QVideoFrameFormat::PixelFormat format )**

        Returns an image format equivalent to a video frame pixel **format**. If
        there is no equivalent format **QImage::Format_Invalid**  is returned
        instead.

        **Note:** In general **QImage**  does not handle YUV formats.
        """
        ...

    @staticmethod
    def pixelFormatFromImageFormat(
        format: QtGui.QImage.Format,
    ) -> "QVideoFrameFormat.PixelFormat":
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#pixelFormatFromImageFormat

        **[static] QVideoFrameFormat::PixelFormat
        QVideoFrameFormat::pixelFormatFromImageFormat(QImage::Format format )**

        Returns a video pixel format equivalent to an image **format**. If there
        is no equivalent format **QVideoFrameFormat::Format_Invalid**  is
        returned instead.

        **Note:** In general **QImage**  does not handle YUV formats.
        """
        ...

    def setMirrored(self, mirrored: bool) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setMirrored

        **void QVideoFrameFormat::setMirrored(bool mirrored )**

        Sets if the surface is **mirrored** around its vertical axis. This is
        typically needed for video frames coming from a front camera of a mobile
        device. Default value is false.

        **Note:** The mirroring here differs from **QImage::mirrored** , as a
        vertically mirrored **QImage**  will be mirrored around its x-axis.

        **See also** **isMirrored** ().
        """
        ...

    def isMirrored(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#isMirrored

        **bool QVideoFrameFormat::isMirrored() const**

        Returns `true` if the surface is mirrored around its vertical axis. This
        is typically needed for video frames coming from a front camera of a
        mobile device.

        **Note:** The mirroring here differs from **QImage::mirrored** , as a
        vertically mirrored **QImage**  will be mirrored around its x-axis.
        """
        ...

    def setYCbCrColorSpace(
        self, colorSpace: "QVideoFrameFormat.YCbCrColorSpace"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setYCbCrColorSpace

        **void
        QVideoFrameFormat::setYCbCrColorSpace(QVideoFrameFormat::YCbCrColorSpace
        space )**

        Sets the Y'CbCr color **space** of a video stream. It is only used with
        raw YUV frame types.

        **See also** **yCbCrColorSpace** ().
        """
        ...

    def yCbCrColorSpace(self) -> "QVideoFrameFormat.YCbCrColorSpace":
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#yCbCrColorSpace

        **QVideoFrameFormat::YCbCrColorSpace
        QVideoFrameFormat::yCbCrColorSpace() const**

        Returns the Y'CbCr color space of a video stream.

        **See also** **setYCbCrColorSpace** ().
        """
        ...

    def setFrameRate(self, rate: float) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setFrameRate

        **void QVideoFrameFormat::setFrameRate(qreal rate )**

        Sets the frame **rate** of a video stream in frames per second.

        **See also** **frameRate** ().
        """
        ...

    def frameRate(self) -> float:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#frameRate

        **qreal QVideoFrameFormat::frameRate() const**

        Returns the frame rate of a video stream in frames per second.

        **See also** **setFrameRate** ().
        """
        ...

    def setScanLineDirection(self, direction: "QVideoFrameFormat.Direction") -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setScanLineDirection

        **void
        QVideoFrameFormat::setScanLineDirection(QVideoFrameFormat::Direction
        direction )**

        Sets the **direction** of scan lines.

        **See also** **scanLineDirection** ().
        """
        ...

    def scanLineDirection(self) -> "QVideoFrameFormat.Direction":
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#scanLineDirection

        **QVideoFrameFormat::Direction QVideoFrameFormat::scanLineDirection()
        const**

        Returns the direction of scan lines.

        **See also** **setScanLineDirection** ().
        """
        ...

    def setViewport(self, viewport: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setViewport

        **void QVideoFrameFormat::setViewport(const QRect & viewport )**

        Sets the viewport of a video stream to **viewport**.

        **See also** **viewport** ().
        """
        ...

    def viewport(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#viewport

        **QRect QVideoFrameFormat::viewport() const**

        Returns the viewport of a video stream.

        The viewport is the region of a video frame that is actually displayed.

        By default the viewport covers an entire frame.

        **See also** **setViewport** ().
        """
        ...

    def planeCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#planeCount

        **int QVideoFrameFormat::planeCount() const**

        Returns the number of planes used. This number is depending on the pixel
        format and is 1 for RGB based formats, and a number between 1 and 3 for
        YUV based formats.
        """
        ...

    def frameHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#frameHeight

        **int QVideoFrameFormat::frameHeight() const**

        Returns the height of frame in a video stream.
        """
        ...

    def frameWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#frameWidth

        **int QVideoFrameFormat::frameWidth() const**

        Returns the width of frames in a video stream.

        **See also** **frameSize** () and **frameHeight** ().
        """
        ...

    @typing.overload
    def setFrameSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setFrameSize

        **void QVideoFrameFormat::setFrameSize(const QSize & size )**

        Sets the size of frames in a video stream to **size**.

        This will reset the **viewport** () to fill the entire frame.

        **See also** **frameSize** ().
        """
        ...

    @typing.overload
    def setFrameSize(self, width: int, height: int) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#setFrameSize-1

        **void QVideoFrameFormat::setFrameSize(int width , int height )**

        This is an overloaded function.

        Sets the **width** and **height** of frames in a video stream.

        This will reset the **viewport** () to fill the entire frame.
        """
        ...

    def frameSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#frameSize

        **QSize QVideoFrameFormat::frameSize() const**

        Returns the dimensions of frames in a video stream.

        **See also** **setFrameSize** (), **frameWidth** (), and **frameHeight**
        ().
        """
        ...

    def pixelFormat(self) -> "QVideoFrameFormat.PixelFormat":
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#pixelFormat

        **QVideoFrameFormat::PixelFormat QVideoFrameFormat::pixelFormat()
        const**

        Returns the pixel format of frames in a video stream.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframeformat.html#isValid

        **bool QVideoFrameFormat::isValid() const**

        Identifies if a video surface format has a valid pixel format and frame
        size.

        Returns true if the format is valid, and false otherwise.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QCompassReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qcompassreading.html

    **Detailed Description**

    **QCompassReading Units**

    The compass returns the azimuth of the device as degrees from magnetic north
    in a clockwise direction based on the top of the device, as defined by
    **QScreen::nativeOrientation** . There is also a value to indicate the
    calibration status of the device. If the device is not calibrated the
    azimuth may not be accurate.

    Digital compasses are susceptible to magnetic interference and may need
    calibration after being placed near anything that emits a magnetic force.
    Accuracy of the compass can be affected by any ferrous materials that are
    nearby.

    The calibration status of the device is measured as a number from 0 to 1. A
    value of 1 is the highest level that the device can support and 0 is the
    worst.
    """

    def setCalibrationLevel(self, calibrationLevel: float) -> None:
        """
        https://doc.qt.io/qt-6/qcompassreading.html#setCalibrationLevel

        **void QCompassReading::setCalibrationLevel(qreal calibrationLevel )**

        Sets the calibration level of the reading to **calibrationLevel**.

        **See also** **calibrationLevel** ().
        """
        ...

    def calibrationLevel(self) -> float:
        """
        https://doc.qt.io/qt-6/qcompassreading.html#calibrationLevel-prop

        **[read-only] calibrationLevel : const qreal**

        This property holds the calibration level of the reading.

        Measured as a value from 0 to 1 with higher values being better.

        **Access functions:**

        qreal **calibrationLevel** () const

        **See also** **QCompassReading Units** .

        **Member Function Documentation**
        """
        ...

    def setAzimuth(self, azimuth: float) -> None:
        """
        https://doc.qt.io/qt-6/qcompassreading.html#setAzimuth

        **void QCompassReading::setAzimuth(qreal azimuth )**

        Sets the **azimuth** of the device.

        **See also** **azimuth** () and **QCompassReading Units** .
        """
        ...

    def azimuth(self) -> float:
        """
        https://doc.qt.io/qt-6/qcompassreading.html#azimuth-prop

        **[read-only] azimuth : const qreal**

        This property holds the azimuth of the device.

        Measured in degrees from magnetic north in a clockwise direction based
        on the top of the device, as defined by **QScreen::nativeOrientation** .

        **Access functions:**

        qreal **azimuth** () const

        **See also** **QCompassReading Units** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QDBusAbstractAdaptor import QDBusAbstractAdaptor as QDBusAbstractAdaptor
from ._QDBusAbstractInterface import QDBusAbstractInterface as QDBusAbstractInterface
from ._QDBusArgument import QDBusArgument as QDBusArgument
from ._QDBus import QDBus as QDBus
from ._QDBusConnection import QDBusConnection as QDBusConnection
from ._QDBusConnectionInterface import (
    QDBusConnectionInterface as QDBusConnectionInterface,
)
from ._QDBusError import QDBusError as QDBusError
from ._QDBusObjectPath import QDBusObjectPath as QDBusObjectPath
from ._QDBusSignature import QDBusSignature as QDBusSignature
from ._QDBusVariant import QDBusVariant as QDBusVariant
from ._QDBusInterface import QDBusInterface as QDBusInterface
from ._QDBusMessage import QDBusMessage as QDBusMessage
from ._QDBusPendingCall import QDBusPendingCall as QDBusPendingCall
from ._QDBusPendingCallWatcher import QDBusPendingCallWatcher as QDBusPendingCallWatcher
from ._QDBusServiceWatcher import QDBusServiceWatcher as QDBusServiceWatcher
from ._QDBusUnixFileDescriptor import QDBusUnixFileDescriptor as QDBusUnixFileDescriptor
from ._QDBusPendingReply import QDBusPendingReply as QDBusPendingReply
from ._QDBusReply import QDBusReply as QDBusReply
